/*!
 * @file ConnectionMgr.js
 *
 * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
 * @note Designed with Titanium for iOS and Android devices
 * @note This file contains propritary information
 * @copyright 2014 Riverside MFG LLC
 * @section DESCRIPTION
 *
 * This source file contains the connection manager window class which handles
 * connection to the system.
 */

var uiStyle = require('UI/style');
var window;
var controls = {};                        
var data = undefined;
var startCallback = null;
var stopCallback = null;
var successCallback = null;

module.exports = {
    /*!
     * This function sets up the connection manager window
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/21/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'init': function(start,stop,success){
        startCallback = start;
        stopCallback = stop;
        successCallback = success;
        var w = Titanium.Platform.displayCaps.platformWidth,h = Titanium.Platform.displayCaps.platformHeight,temp,cont;
        window = Titanium.UI.createWindow(uiStyle._extend(uiStyle.window, {
            title:'Connection Manager'
        }));
        cont = Titanium.UI.createView(uiStyle.container);
        window.add(cont);
        
        temp = Titanium.UI.createLabel(uiStyle._extend(uiStyle.textMedium,{
            text:"Please Login Below",
            width:'100%',
            top: 70
        }));
        cont.add(temp);
        temp = Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{
            text:"Hostname:",
            width:'30%',
            left: '0',
            top: 140
        }));
        cont.add(temp);
        controls['hostname'] = Titanium.UI.createTextField(uiStyle._extend(uiStyle.textBox,{
            top:130,
            left:'30%',
            width:'60%',
            hintText:'Enter Hostname',
            value: '10.0.0.1'
            //value:'172.21.103.25'
        }));
        cont.add(controls['hostname']);
        temp = Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{
            text:"Access Key:",
            width:'30%',
            left: '0',
            top: 200
        }));
        cont.add(temp);
        controls['password'] = Titanium.UI.createTextField(uiStyle._extend(uiStyle.textBox,{
            top:190,
            left:'30%',
            width:'60%',
            hintText:'Password',
            value: '',
            passwordMask: true
        }));
        cont.add(controls['password']);
        temp = Titanium.UI.createButton(uiStyle._extend(uiStyle.stdButton,{
            'top': 250,
            'title': 'Access System'
        }));
        temp.addEventListener('click', function(e){
            if(controls['hostname'].value == '' || controls['password'].value == ''){
                return;
            }
            data = undefined;
            controls['error'].hide();
            controls['loading'].show();
            if(startCallback != null){
                startCallback(controls['hostname'].value);
            }
            module.exports._fetchData();
        });
        cont.add(temp);
        controls['loading'] = Titanium.UI.createActivityIndicator({
          color: '#FF0000',
          font: {fontSize:25, fontWeight:'bold'},
          message: 'Accessing System...',
          style: (Ti.Platform.name === 'iPhone OS')?Ti.UI.iPhone.ActivityIndicatorStyle.BIG:Ti.UI.ActivityIndicatorStyle.BIG,
          top: 330,
          height:'80',
          width:'100%',
        });
        cont.add(controls['loading']);
        controls['error'] = Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{
            text:"",
            color: "#F8FF38",
            width:'100%',
            top: 330,
            visible: false
        }));
        cont.add(controls['error']);

    },
    /*!
     * This function opens the window
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/21/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'open': function(){
        data = undefined;
        window.open();
    },
    /*!
     * This function closes the window
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/21/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'close': function(){
        window.close();    
    },
    
    'pushData': function(rx){
        data = rx;
    },
    '_fetchData': function(){
        var timeout = 0;
        var helper = function(){
            timeout++;
            if(timeout > 5){
                //no system found
                controls['loading'].hide();
                controls['error'].show();
                controls['error'].text = 'Could not find a system on the network!';
                
                if(stopCallback != null){
                    stopCallback();
                }
            }
            else if(!data || !data.s.cfg){
                setTimeout(helper,1000);
                
            }
            else if(data.s.cfg.key != controls['password'].value){
               controls['loading'].hide();
                controls['error'].show();
                controls['error'].text = 'Invalid Passcode!';
                
                if(stopCallback != null){
                    stopCallback();
                }
            }
            else{
                Ti.API.log('(ConnectionMgr.js): Successfully Connected to System!');
                controls['loading'].hide();
                if(successCallback != null){
                    successCallback();
                }
            }
        };
        helper();
    }
};
