/*!
 * @file 1-system.js
 *
 * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
 * @note Designed with Titanium for iOS and Android devices
 * @note This file contains propritary information
 * @copyright 2014 Riverside MFG LLC
 * @section DESCRIPTION
 *
 * This source file contains the class to draw/update window: CFG 1-system
 */

var window;                /*!< Window object for self */
var activeCtrls = {};    /*!< Controls on window object */
var sendBack = {};

module.exports = {
    /*!
     * This flag determins if the current window should be skipped in the rotation of windows
     */
    'skip': false,
    /*!
     * This is the ID of the page
     */
    'id':'cfg.sys',
    /*!
     * This function is called to switch to normal mode and should be remapped by the WindowManager
     */
    'switchToNormal': function(){},
    /*!
     * This function is called to go to page 0 on the configuration menu
     */
    'gotoPage0': function(){},
    /*!
     * This function sets up the display elements for the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'init': function(uiStyle,swipe,actionControllers){
        var cont,views=[],temp;
        style = uiStyle;
        window = Titanium.UI.createWindow(uiStyle._extend(uiStyle.window, {
            title:'Configuration: System Information'
        }));
        cont = Titanium.UI.createView(uiStyle.containerCanvas);
        window.add(cont);
        window.addEventListener('swipe',swipe);
        /*window.addEventListener('android:back',function(e){
			back();
        	window.close();
        });*/
        
        //title block
        views[0] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '1%',height: '15%',width: '98%'}));
        cont.add(views[0]);
        views[0].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textMedium,{text:"System Information Pg. 1",width:'100%',height:'100%',left: '0',top: '0'})));
        views[0].children[0].addEventListener('click',module.exports.gotoPage0);
        
        //data block
        views[1] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '17%',height: '82%',width: '98%'}));
        cont.add(views[1]);
        
        //truck ID
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"TRUCK ID:",width:'25%',height:55,left: '0%',top: '5%'})));
        activeCtrls['truckId'] = new actionControllers.TextEntry(uiStyle._extend(uiStyle.stdButton,{title:"12345",width:'22%',top: '5%',left: '25%'}),function(toSend){
            sendBack={
            	'rt':{
            		'tid':toSend
            	}
            };
        });
        views[1].add(activeCtrls['truckId'].getObject());
        
        //save & exit
        temp = Titanium.UI.createButton(uiStyle._extend(uiStyle.stdButton,{title:"Save & Exit",width:'40%',top: '80%',left: '4%'}));
        temp.addEventListener('click', function(e){
            module.exports.switchToNormal();
        });
        views[1].add(temp);
        
        //software vers
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textMediumUL,{text:"Software Versions",width:'50%',height:'15%',left: '50%',top: '1%'})));
  
        activeCtrls['v1'] = Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"",width:'25%',height:'85%',left: '50%',top: '15%',verticalAlign: Titanium.UI.TEXT_VERTICAL_ALIGNMENT_TOP }));
        activeCtrls['v2'] = Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"",width:'25%',height:'85%',left: '75%',top: '15%',verticalAlign: Titanium.UI.TEXT_VERTICAL_ALIGNMENT_TOP }));
        views[1].add(activeCtrls['v1']);
        views[1].add(activeCtrls['v2']);
  
    },
    /*!
     * This function opens the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'open': function(){
        Ti.API.log('opening');
        Ti.API.log(window);
        window.open();
    },
    /*!
     * This function closes the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'close': function(){
        window.close();
    },
    /*!
     * This function updates the active controls on the current window view
     * with new data pushed from the stack.
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @param data JSON data object
     */
    'update': function(data){
        var str;
        if(!data.s.rt || !data.s.rt.v){
            return;
        }
        activeCtrls['truckId'].value(data.s.rt.tid);
        //sw1 sw2
        str = 'BDL: ' + data.s.rt.v[0] + "\nGUI: " + data.s.rt.v[1] + "\nDrivers: "+data.s.rt.v[2] + "\nWiFi: "+ data.s.rt.v[3];
        
        if(data.s.rt.v[5] != '0.0.0'){
            str += "\nPanel 1: "+data.s.rt.v[5];
        }
        if(data.s.rt.v[6] != '0.0.0'){
            str += "\nPanel 2: "+data.s.rt.v[6];
        }
        if(data.s.rt.v[7] != '0.0.0'){
            str += "\nPanel 3: "+data.s.rt.v[7];
        }
        if(data.s.rt.v[8] != '0.0.0'){
            str += "\nPanel 4: "+data.s.rt.v[8];
        }
        activeCtrls['v1'].text = str;
        str = 'CTRL: '+data.s.rt.v[4];
        if(data.s.rt.v[9] != '0.0.0'){
            str += "\nMaster: "+data.s.rt.v[9];
        }
        if(data.s.rt.v[10] != '0.0.0'){
            str += "\nMotor: "+data.s.rt.v[10];
        }
        if(data.s.rt.v[11] != '0.0.0'){
            str += "\nSlave 1: "+data.s.rt.v[11];
        }
        if(data.s.rt.v[12] != '0.0.0'){
            str += "\nSlave 2: "+data.s.rt.v[12];
        }
        if(data.s.rt.v[13] != '0.0.0'){
            str += "\nSlave 3: "+data.s.rt.v[13];
        }
        if(data.s.rt.v[14] != '0.0.0'){
            str += "\nSlave 4: "+data.s.rt.v[14];
        }
        activeCtrls['v2'].text = str;
    },
    /*!
     * This function gets an object of data to send back to the server
     * based on any user requested actions
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @return object of data
     */
    'getDataTx': function(){
        var temp = sendBack;
        sendBack = {};
        return temp;
    }
    
};