/*!
 * @file 10-spreader.js
 *
 * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
 * @note Designed with Titanium for iOS and Android devices
 * @note This file contains propritary information
 * @copyright 2014 Riverside MFG LLC
 * @section DESCRIPTION
 *
 * This source file contains the class to draw/update window: CFG 10-spreader
 */

var window;                /*!< Window object for self */
var activeCtrls = {};    /*!< Controls on window object */
var sendBack = {};        /*!< Object which contains commands to send back to server */
var style;                /*!< UI Style Wrapper */

module.exports = {
    /*!
     * This flag determins if the current window should be skipped in the rotation of windows
     */
    'skip': false,
    /*!
     * This is the ID of the page
     */
    'id':'cfg.sprd3',
    /*!
     * This function is called to switch to normal mode and should be remapped by the WindowManager
     */
    'switchToNormal': function(){},
    /*!
     * This function is called to go to page 0 on the configuration menu
     */
    'gotoPage0': function(){},
    /*!
     * This function sets up the display elements for the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'init': function(uiStyle,swipe,actionControllers){
        var cont,views=[];
        style = uiStyle;
        window = Titanium.UI.createWindow(uiStyle._extend(uiStyle.window, {
            title:'Configuration: Spreader Presets'
        }));
        cont = Titanium.UI.createView(uiStyle.containerCanvas);
        window.add(cont);
        window.addEventListener('swipe',swipe);
        
        //title block
        views[0] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '1%',height: '15%',width: '98%'}));
        cont.add(views[0]);
        views[0].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textMedium,{text:"Spreader Presets Pg. 10",width:'100%',height:'100%',left: '0',top: '0'})));
        views[0].children[0].addEventListener('click',module.exports.gotoPage0);
        
        //data block
        views[1] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '17%',height: '82%',width: '98%'}));
        cont.add(views[1]);
        
        //titles
        views[1].add(Titanium.UI.createView({width : 6, left : '36%', height : '100%', backgroundColor: '#009933', top : '0'}));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Fixed Preset 1",width:'35%',height:'16%',left: '0%',top: '0',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Fixed Preset 2",width:'35%',height:'16%',left: '0%',top: '16%',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Fixed Preset 3",width:'35%',height:'16%',left: '0%',top: '32%',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Fixed Preset 4",width:'35%',height:'16%',left: '0%',top: '48%',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Fixed Preset 5",width:'35%',height:'16%',left: '0%',top: '64%',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Fixed Preset 6",width:'35%',height:'16%',left: '0%',top: '80%',textAlign: 'right'})));
        
        //controls
        activeCtrls["preset1"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"10Hz",width:250,left:'40%',top: '2%'}),function(toSend){
            sendBack = {
            	'cfg':{
            		'sprdm':{
            			'10':{'0':toSend}
            		}
            	}
            };
        },false,{min:0,max:30,inc:1,multi:50,units:' Lbs/Mi'});
        views[1].add(activeCtrls["preset1"].getObject());
        
        activeCtrls["preset2"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"10Hz",width:250,left:'40%',top: '18%'}),function(toSend){
        	sendBack = {
            	'cfg':{
            		'sprdm':{
            			'10':{'1':toSend}
            		}
            	}
            };
        },false,{min:0,max:30,inc:1,multi:50,units:' Lbs/Mi'});
        views[1].add(activeCtrls["preset2"].getObject());
        
        activeCtrls["preset3"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"10Hz",width:250,left:'40%',top: '34%'}),function(toSend){
        	sendBack = {
            	'cfg':{
            		'sprdm':{
            			'10':{'2':toSend}
            		}
            	}
            };
        },false,{min:0,max:30,inc:1,multi:50,units:' Lbs/Mi'});
        views[1].add(activeCtrls["preset3"].getObject());
        
        activeCtrls["preset4"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"10Hz",width:250,left:'40%',top: '50%'}),function(toSend){
        	sendBack = {
            	'cfg':{
            		'sprdm':{
            			'10':{'3':toSend}
            		}
            	}
            };
        },false,{min:0,max:30,inc:1,multi:50,units:' Lbs/Mi'});
        views[1].add(activeCtrls["preset4"].getObject());
        
        activeCtrls["preset5"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"10Hz",width:250,left:'40%',top: '66%'}),function(toSend){
        	sendBack = {
            	'cfg':{
            		'sprdm':{
            			'10':{'4':toSend}
            		}
            	}
            };
        },false,{min:0,max:30,inc:1,multi:50,units:' Lbs/Mi'});
        views[1].add(activeCtrls["preset5"].getObject());
        
         activeCtrls["preset6"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"10Hz",width:250,left:'40%',top: '82%'}),function(toSend){
        	sendBack = {
            	'cfg':{
            		'sprdm':{
            			'10':{'5':toSend}
            		}
            	}
            };
        },false,{min:0,max:30,inc:1,multi:50,units:' Lbs/Mi'});
        views[1].add(activeCtrls["preset6"].getObject());
        
    },
    /*!
     * This function opens the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'open': function(){
        Ti.API.log('opening');
        Ti.API.log(window);
        window.open();
    },
    /*!
     * This function closes the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'close': function(){
        window.close();
    },
    /*!
     * This function updates the active controls on the current window view
     * with new data pushed from the stack.
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @param data JSON data object
     */
    'update': function(data){
        if(data == false){
            return;
        }
        activeCtrls["preset1"].value(data.s.cfg.sprdm[10][0]);
        activeCtrls["preset2"].value(data.s.cfg.sprdm[10][1]);
        activeCtrls["preset3"].value(data.s.cfg.sprdm[10][2]);
        activeCtrls["preset4"].value(data.s.cfg.sprdm[10][3]);
        activeCtrls["preset5"].value(data.s.cfg.sprdm[10][4]);
        activeCtrls["preset6"].value(data.s.cfg.sprdm[10][5]);
    },
    /*!
     * This function gets an object of data to send back to the server
     * based on any user requested actions
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @return object of data
     */
    'getDataTx': function(){
        var temp = sendBack;
        sendBack = {};
        return temp;
    }
    
};