/*!
 * @file 11-spreader.js
 *
 * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
 * @note Designed with Titanium for iOS and Android devices
 * @note This file contains propritary information
 * @copyright 2014 Riverside MFG LLC
 * @section DESCRIPTION
 *
 * This source file contains the class to draw/update window: CFG 11-spreader
 */

var window;                /*!< Window object for self */
var activeCtrls = {};    /*!< Controls on window object */
var sendBack = {};        /*!< Object which contains commands to send back to server */
var style;                /*!< UI Style Wrapper */

module.exports = {
    /*!
     * This flag determins if the current window should be skipped in the rotation of windows
     */
    'skip': false,
    /*!
     * This is the ID of the page
     */
    'id':'cfg.sprd4',
    /*!
     * This function is called to go to page 0 on the configuration menu
     */
    'gotoPage0': function(){},
    /*!
     * This function sets up the display elements for the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'init': function(uiStyle,swipe,actionControllers){
        var cont,views=[];
        style = uiStyle;
        window = Titanium.UI.createWindow(uiStyle._extend(uiStyle.window, {
            title:'Configuration: Spreader Calibration'
        }));
        cont = Titanium.UI.createView(uiStyle.containerCanvas);
        window.add(cont);
        window.addEventListener('swipe',swipe);
        
        //title block
        views[0] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '1%',height: '15%',width: '98%'}));
        cont.add(views[0]);
        views[0].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textMedium,{text:"Spreader Calibration Pg. 11",width:'100%',height:'100%',left: '0',top: '0'})));
        views[0].children[0].addEventListener('click',module.exports.gotoPage0);
        
        //data block
        views[1] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '17%',height: '82%',width: '98%'}));
        cont.add(views[1]);
        
        //titles
        views[1].add(Titanium.UI.createView({width : 6, left : '36%', height : '100%', backgroundColor: '#009933', top : '0'}));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Prod Name",width:'35%',height:'16%',left: '0%',top: '0',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Cal (OL)",width:'35%',height:'16%',left: '0%',top: '16%',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Cal (CL)",width:'35%',height:'16%',left: '0%',top: '32%',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Spreader Cal",width:'35%',height:'16%',left: '0%',top: '48%',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Ground Speed Const",width:'35%',height:'16%',left: '0%',top: '64%',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Ground Speed Cal",width:'35%',height:'16%',left: '0%',top: '80%',textAlign: 'right'})));
        
        //controls
        activeCtrls['prodName'] = new actionControllers.TextEntry(uiStyle._extend(uiStyle.stdButton,{title:"",width:250,left:'40%',top: '2%'}),function(toSend){
        	sendBack = {
            	'cfg':{
            		'sprdc':{
            			'0':toSend
            		}
            	}
            };
        });
        views[1].add(activeCtrls['prodName'].getObject());
        
        activeCtrls['calol'] = new actionControllers.TextEntry(uiStyle._extend(uiStyle.stdButton,{title:"",width:250,left:'40%',top: '18%'}),function(toSend){
        	sendBack = {
            	'cfg':{
            		'sprdc':{
            			'1':parseFloat(toSend)
            		}
            	}
            };
        },true);
        views[1].add(activeCtrls['calol'].getObject());
     
        activeCtrls['calcl'] = new actionControllers.TextEntry(uiStyle._extend(uiStyle.stdButton,{title:"",width:250,left:'40%',top: '34%'}),function(toSend){
        	sendBack = {
            	'cfg':{
            		'sprdc':{
            			'2':parseFloat(toSend)
            		}
            	}
            };
        },true);
        views[1].add(activeCtrls['calcl'].getObject());
        
        activeCtrls['calBtn'] = new actionControllers.Calibrate(uiStyle._extend(uiStyle.stdButton,{title:"Calibrate",width:250,left:'40%',top: '50%'}),function(cmd,data){
            sendBack['cal'] = {};
            sendBack['cal'][cmd] = data;
        },0);
        views[1].add(activeCtrls['calBtn'].getObject());
        
        activeCtrls['calgs'] = new actionControllers.TextEntry(uiStyle._extend(uiStyle.stdButton,{title:"",width:250,left:'40%',top: '66%'}),function(toSend){
        	sendBack = {
            	'cfg':{
            		'sprdc':{
            			'3':parseFloat(toSend)
            		}
            	}
            };
        },true);
        views[1].add(activeCtrls['calgs'].getObject());
        
        activeCtrls["gsCal"] = new actionControllers.CommandElement(uiStyle._extend(uiStyle.stdButton,{title:"Calibrate",width:150,top: '82%',left: '40%'}),function(data){
            sendBack = {
            	'cmd':{
            		'gscal':data
            	}
            };
        },false);
        views[1].add(activeCtrls["gsCal"].getObject());
        
        activeCtrls['speed'] = Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"00 MPH",width:100,height:'16%',left: '65%',top: '82%'}));
        views[1].add(activeCtrls['speed']);

    },
    /*!
     * This function opens the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'open': function(){
        Ti.API.log('opening');
        Ti.API.log(window);
        window.open();
    },
    /*!
     * This function closes the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'close': function(){
        window.close();
    },
    /*!
     * This function updates the active controls on the current window view
     * with new data pushed from the stack.
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @param data JSON data object
     */
    'update': function(data){
        if(data == false){
            return;
        }
        activeCtrls['prodName'].value(data.s.cfg.sprdc[0]);
        activeCtrls['calol'].value(data.s.cfg.sprdc[1]);
        activeCtrls['calcl'].value(data.s.cfg.sprdc[2]);
        activeCtrls['calBtn'].value(data.s.cfg.cmd);
        activeCtrls['calBtn'].data(data.s.cfg.cal,data.s.cfg.sprdm[0]);
        activeCtrls['calgs'].value(data.s.cfg.sprdc[3]);
        activeCtrls['speed'].text = data.d[0].gui[17].toString() +' MPH';
        activeCtrls["gsCal"].value(data.s.cfg.cmd);
    },
    /*!
     * This function gets an object of data to send back to the server
     * based on any user requested actions
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @return object of data
     */
    'getDataTx': function(){
        var temp = sendBack;
        sendBack = {};
        return temp;
    }
    
};