/*!
 * @file 13-equipment.js
 *
 * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
 * @note Designed with Titanium for iOS and Android devices
 * @note This file contains propritary information
 * @copyright 2014 Riverside MFG LLC
 * @section DESCRIPTION
 *
 * This source file contains the class to draw/update window: CFG 13-equipment
 * 
 * This window handles Pre-Wet, Tow Plow and Xzalt configuration (only one can be active at once)
 */

var window;                /*!< Window object for self */
var activeCtrls = {};    /*!< Controls on window object */
var activeLabels = [];    /*!< Controls on window object */
var sendBack = {};        /*!< Object which contains commands to send back to server */
var style;                /*!< UI Style Wrapper */
var views=[];

module.exports = {
    /*!
     * This flag determins if the current window should be skipped in the rotation of windows
     */
    'skip': false,
    /*!
     * This is the ID of the page
     */
    'id':'cfg.equip',
    /*!
     * This function is called to go to page 0 on the configuration menu
     */
    'gotoPage0': function(){},
    /*!
     * This function sets up the display elements for the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'init': function(uiStyle,swipe,actionControllers){
        var cont;
        style = uiStyle;
        window = Titanium.UI.createWindow(uiStyle._extend(uiStyle.window, {
            title:'Configuration: ((Equipment))'
        }));
        cont = Titanium.UI.createView(uiStyle.containerCanvas);
        window.add(cont);
        window.addEventListener('swipe',swipe);
        
        //title block
        views[0] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '1%',height: '15%',width: '98%'}));
        cont.add(views[0]);
        views[0].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textMedium,{text:"((Equipment)) Pg. 13",width:'100%',height:'100%',left: '0',top: '0'})));
        views[0].children[0].addEventListener('click',module.exports.gotoPage0);
        
        //data block
        views[1] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '17%',height: '82%',width: '98%'}));
        cont.add(views[1]);
        
        //titles
        views[1].add(Titanium.UI.createView({width : 6, left : '36%', height : '100%', backgroundColor: '#009933', top : '0'}));
        activeLabels[0] = Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"((Label1))",width:'35%',height:'16%',left: '0%',top: '0',textAlign: 'right'}));
        activeLabels[1] = Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"((Label2))",width:'35%',height:'16%',left: '0%',top: '16%',textAlign: 'right'}));
        activeLabels[2] = Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"((Label3))",width:'35%',height:'16%',left: '0%',top: '32%',textAlign: 'right'}));
        activeLabels[3] = Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"((Label4))",width:'35%',height:'16%',left: '0%',top: '48%',textAlign: 'right'}));
        activeLabels[4] = Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"((Label5))",width:'35%',height:'16%',left: '0%',top: '64%',textAlign: 'right'}));
        activeLabels[5] = Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"((Label6))",width:'35%',height:'16%',left: '0%',top: '80%',textAlign: 'right'}));
        views[1].add(activeLabels[0]);
        views[1].add(activeLabels[1]);
        views[1].add(activeLabels[2]);
        views[1].add(activeLabels[3]);
        views[1].add(activeLabels[4]);
        views[1].add(activeLabels[5]);
        
        views[2] = Titanium.UI.createView(uiStyle._extend({left: '40%',top: '17%',height: '82%',width: '60%'}));
        cont.add(views[2]);
    },
    /*!
     * This is the secondary init function to setup UI elements after we have data
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    firstSetup: function(data){
        views[2].removeAllChildren();
        for(var key in activeCtrls){
            activeCtrls[key].dispose();
        }
        activeCtrls = {};
        
        //xzalt mode
        if(data.d[0].gui[0] == 2){
            window.title = 'Configuration: Xzalt Settings';
            views[0].children[0].text = 'Xzalt Pg. 13';
        }
        //tow plow mode
        else if(data.d[0].gui[0] == 1){
            window.title = 'Configuration: Tow Plow Settings';
            views[0].children[0].text = 'Tow Plow Pg. 13';
            activeLabels[0].text = '2nd Auger Speed';
            activeLabels[1].text = 'Cal (OL)';
            activeLabels[2].text = 'Cal (CL)';
            activeLabels[3].text = 'Auger 2 Cal';
            activeLabels[0].visible = true;
            activeLabels[1].visible = true;
            activeLabels[2].visible = true;
            activeLabels[3].visible = true;
            activeLabels[4].visible = false;
            activeLabels[5].visible = false;
            
            activeCtrls["speed"] = new actionControllers.SliderButton(style._extend(style.stdButton,{title:"",width:250,left:0,top: '2%'}),function(toSend){
	        	sendBack = {
	            	'cfg':{
	            		'tow':{
	            			'0':toSend
	            		}
	            	}
	            };
            },true,{min:0,max:100,inc:1,multi:1,units:'%'});
            views[2].add(activeCtrls["speed"].getObject());
            
            activeCtrls['calol'] = new actionControllers.TextEntry(style._extend(style.stdButton,{title:"",width:250,left:0,top: '18%'}),function(toSend){
        		sendBack = {
	            	'cfg':{
	            		'tow':{
	            			'1':parseFloat(toSend)
	            		}
	            	}
	            };
            },true);
            views[2].add(activeCtrls['calol'].getObject());
            
            activeCtrls['calcl'] = new actionControllers.TextEntry(style._extend(style.stdButton,{title:"",width:250,left:0,top: '34%'}),function(toSend){
        		sendBack = {
	            	'cfg':{
	            		'tow':{
	            			'2':parseFloat(toSend)
	            		}
	            	}
	            };
            },true);
            views[2].add(activeCtrls['calcl'].getObject());
            
                        
            activeCtrls['calBtn'] = new actionControllers.Calibrate(style._extend(style.stdButton,{title:"Calibrate",width:250,left:0,top: '50%'}),function(cmd,data){
           		sendBack['cal'] = {};
            	sendBack['cal'][cmd] = data;
            },1);
            views[2].add(activeCtrls['calBtn'].getObject());
            
        }
        else{
            window.title = 'Configuration: Pre-Wet Settings';
            views[0].children[0].text = 'Pre-Wet Pg. 13';
            activeLabels[0].text = 'Output Speed';
            activeLabels[1].text = 'Control Loop';
            activeLabels[2].text = 'Cal (OL)';
            activeLabels[3].text = 'Cal (CL)';
            activeLabels[4].text = 'Pre-Wet Cal';
            activeLabels[0].visible = true;
            activeLabels[1].visible = true;
            activeLabels[2].visible = true;
            activeLabels[3].visible = true;
            activeLabels[4].visible = true;
            activeLabels[5].visible = false;
            
            activeCtrls["speed"] = new actionControllers.SliderButton(style._extend(style.stdButton,{title:"",width:250,left:0,top: '2%'}),function(toSend){
        		sendBack = {
	            	'cfg':{
	            		'pw':{
	            			'0':toSend
	            		}
	            	}
	            };
            },true,{min:0,max:100,inc:1,multi:1,units:'%'});
            views[2].add(activeCtrls["speed"].getObject());
            
            activeCtrls["cloop"] = new actionControllers.ToggleButton(style._extend(style.stdButton,{title:"10",width:250,top: '18%',left:0}),function(toSend){
        		sendBack = {
	            	'cfg':{
	            		'pw':{
	            			'1':toSend
	            		}
	            	}
	            };
            },[{val:false,text:'Open Loop'},{val:true,text:'Closed Loop'}]);
            activeCtrls["cloop"].value(0);
            views[2].add(activeCtrls["cloop"].getObject());
            
            activeCtrls['calol'] = new actionControllers.TextEntry(style._extend(style.stdButton,{title:"",width:250,left:0,top: '34%'}),function(toSend){
        		sendBack = {
	            	'cfg':{
	            		'pw':{
	            			'2':parseFloat(toSend)
	            		}
	            	}
	            };
            },true);
            views[2].add(activeCtrls['calol'].getObject());
            
            activeCtrls['calcl'] = new actionControllers.TextEntry(style._extend(style.stdButton,{title:"",width:250,left:0,top: '50%'}),function(toSend){
        		sendBack = {
	            	'cfg':{
	            		'pw':{
	            			'3':parseFloat(toSend)
	            		}
	            	}
	            };
            },true);
            views[2].add(activeCtrls['calcl'].getObject());
            
            activeCtrls['calBtn'] = new actionControllers.Calibrate(style._extend(style.stdButton,{title:"Calibrate",width:250,left:0,top: '66%'}),function(cmd,data){
           		sendBack['cal'] = {};
            	sendBack['cal'][cmd] = data;
            },2);
            views[2].add(activeCtrls['calBtn'].getObject());
            
        }
    },
    
    /*!
     * This function opens the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'open': function(){
        Ti.API.log('opening');
        window.open();
    },
    /*!
     * This function closes the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'close': function(){
        window.close();
    },
    /*!
     * This function updates the active controls on the current window view
     * with new data pushed from the stack.
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @param data JSON data object
     */
    'update': function(data){
        if(data == false){
            return;
        }
        if(data.d[0].gui[0] == 2){
            
        }
        else if(data.d[0].gui[0] == 1){
            activeCtrls["speed"].value(data.s.cfg.tow[0]);
            activeCtrls["calol"].value(data.s.cfg.tow[1]);
            activeCtrls["calcl"].value(data.s.cfg.tow[2]);
        }
        else{
            activeCtrls["speed"].value(data.s.cfg.pw[0]);
            activeCtrls["cloop"].value(data.s.cfg.pw[1]);
            activeCtrls["calol"].value(data.s.cfg.pw[2]);
            activeCtrls["calcl"].value(data.s.cfg.pw[3]);
            activeCtrls['calBtn'].value(data.s.cfg.cmd);
            activeCtrls['calBtn'].data(data.s.cfg.cal,data.s.cfg.pw[0]);
        }
    },
    /*!
     * This function gets an object of data to send back to the server
     * based on any user requested actions
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @return object of data
     */
    'getDataTx': function(){
        var temp = sendBack;
        sendBack = {};
        return temp;
    }
    
};