/*!
 * @file 14-antiice.js
 *
 * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
 * @note Designed with Titanium for iOS and Android devices
 * @note This file contains propritary information
 * @copyright 2014 Riverside MFG LLC
 * @section DESCRIPTION
 *
 * This source file contains the class to draw/update window: CFG 14-antiice
 */

var window;                /*!< Window object for self */
var activeCtrls = {};    /*!< Controls on window object */
var sendBack = {};        /*!< Object which contains commands to send back to server */
var style;                /*!< UI Style Wrapper */

module.exports = {
    /*!
     * This flag determins if the current window should be skipped in the rotation of windows
     */
    'skip': false,
    /*!
     * This is the ID of the page
     */
    'id':'cfg.aice',
    /*!
     * This function is called to go to page 0 on the configuration menu
     */
    'gotoPage0': function(){},
    /*!
     * This function sets up the display elements for the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'init': function(uiStyle,swipe,actionControllers){
        var cont,views=[];
        style = uiStyle;
        window = Titanium.UI.createWindow(uiStyle._extend(uiStyle.window, {
            title:'Configuration: Anti-Ice'
        }));
        cont = Titanium.UI.createView(uiStyle.containerCanvas);
        window.add(cont);
        window.addEventListener('swipe',swipe);
        
        //title block
        views[0] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '1%',height: '15%',width: '98%'}));
        cont.add(views[0]);
        views[0].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textMedium,{text:"Anti-Ice Pg. 14",width:'100%',height:'100%',left: '0',top: '0'})));
        views[0].children[0].addEventListener('click',module.exports.gotoPage0);
        
        //data block
        views[1] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '17%',height: '82%',width: '98%'}));
        cont.add(views[1]);
        
        //titles
        views[1].add(Titanium.UI.createView({width : 6, left : '36%', height : '100%', backgroundColor: '#009933', top : '0'}));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Output Speed",width:'35%',height:'16%',left: '0%',top: '0',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Cal",width:'35%',height:'16%',left: '0%',top: '16%',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Preset Mode",width:'35%',height:'16%',left: '0%',top: '32%',textAlign: 'right'})));
        activeCtrls['lbl-preset1'] = Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Preset 1",width:'35%',height:'16%',left: '0%',top: '48%',textAlign: 'right'}));
        activeCtrls['lbl-preset2'] = Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Preset 2",width:'35%',height:'16%',left: '0%',top: '64%',textAlign: 'right'}));
        activeCtrls['lbl-preset3'] = Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Preset 3",width:'35%',height:'16%',left: '0%',top: '80%',textAlign: 'right'}));
        views[1].add(activeCtrls['lbl-preset1']);
        views[1].add(activeCtrls['lbl-preset2']);
        views[1].add(activeCtrls['lbl-preset3']);

        //controls
        activeCtrls["speed"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"10Hz",width:250,left:'40%',top: '2%'}),function(toSend){
        	sendBack = {
	            'cfg':{
	            	'aice':{
	            		'0':toSend
	            	}
	            }
	        };
        },true,{min:0,max:100,inc:1,multi:1,units:'%'});
        views[1].add(activeCtrls["speed"].getObject());
        
        activeCtrls['cal'] = new actionControllers.TextEntry(uiStyle._extend(uiStyle.stdButton,{title:"",width:250,left:'40%',top: '18%'}),function(toSend){
        	sendBack = {
	            'cfg':{
	            	'aice':{
	            		'1':parseFloat(toSend)
	            	}
	            }
	        };
        },true);
        views[1].add(activeCtrls['cal'].getObject());
        
  
        activeCtrls["mode"] = new actionControllers.ToggleButton(uiStyle._extend(uiStyle.stdButton,{title:"10",width:250,top: '34%',left:'40%'}),function(toSend){
        	sendBack = {
	            'cfg':{
	            	'aice':{
	            		'2':toSend
	            	}
	            }
	        };
        },[{val:true,text:'Fixed'},{val:false,text:'Range'}]);
        activeCtrls["mode"].value(1);
        views[1].add(activeCtrls["mode"].getObject());
        
        activeCtrls["preset1"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"10Hz",width:250,left:'40%',top: '50%'}),function(toSend){
        	sendBack = {
	            'cfg':{
	            	'aice':{
	            		'3':toSend
	            	}
	            }
	        };
        },false,{min:0,max:200,inc:1,multi:1,units:' Gal/Mi'});
        views[1].add(activeCtrls["preset1"].getObject());
        
        activeCtrls["preset2"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"10Hz",width:250,left:'40%',top: '66%'}),function(toSend){
         	sendBack = {
	            'cfg':{
	            	'aice':{
	            		'4':toSend
	            	}
	            }
	        };
        },false,{min:0,max:200,inc:1,multi:1,units:' Gal/Mi'});
        views[1].add(activeCtrls["preset2"].getObject());
        
         activeCtrls["preset3"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"10Hz",width:250,left:'40%',top: '82%'}),function(toSend){
        	sendBack = {
	            'cfg':{
	            	'aice':{
	            		'5':toSend
	            	}
	            }
	        };
        },false,{min:0,max:200,inc:1,multi:1,units:' Gal/Mi'});
        views[1].add(activeCtrls["preset3"].getObject());
    },
    /*!
     * This function opens the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'open': function(){
        Ti.API.log('opening');
        Ti.API.log(window);
        window.open();
    },
    /*!
     * This function closes the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'close': function(){
        window.close();
    },
    /*!
     * This function updates the active controls on the current window view
     * with new data pushed from the stack.
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @param data JSON data object
     */
    'update': function(data){
        if(data == false){
            return;
        }
        
        if(data.s.cfg.aice[2] == 1){
            activeCtrls['lbl-preset1'].text = 'Preset 1';
            activeCtrls['lbl-preset2'].text = 'Preset 2';
            activeCtrls['lbl-preset2'].visible = true;
            activeCtrls["preset3"].show();
        }
        else{
            activeCtrls['lbl-preset1'].text = 'Range Low';
            activeCtrls['lbl-preset2'].text = 'Range High';
            activeCtrls['lbl-preset3'].visible = false;
            activeCtrls["preset3"].hide();
        }
        
        activeCtrls["speed"].value(data.s.cfg.aice[0]);
        activeCtrls["cal"].value(data.s.cfg.aice[1]);
        activeCtrls["mode"].value(data.s.cfg.aice[2]);
        activeCtrls["preset1"].value(data.s.cfg.aice[3]);
        activeCtrls["preset2"].value(data.s.cfg.aice[4]);
        activeCtrls["preset3"].value(data.s.cfg.aice[5]);
    },
    /*!
     * This function gets an object of data to send back to the server
     * based on any user requested actions
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @return object of data
     */
    'getDataTx': function(){
        var temp = sendBack;
        sendBack = {};
        return temp;
    }
    
};