/*!
 * @file 3-datalogging.js
 *
 * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
 * @note Designed with Titanium for iOS and Android devices
 * @note This file contains propritary information
 * @copyright 2014 Riverside MFG LLC
 * @section DESCRIPTION
 *
 * This source file contains the class to draw/update window: CFG 3-datalogging
 */

var window;                /*!< Window object for self */
var activeCtrls = {};    /*!< Controls on window object */
var sendBack = {};

module.exports = {
    /*!
     * This flag determins if the current window should be skipped in the rotation of windows
     */
    'skip': false,
    /*!
     * This is the ID of the page
     */
    'id':'cfg.dl1',
    /*!
     * This function is called to switch to normal mode and should be remapped by the WindowManager
     */
    'switchToNormal': function(){},
    /*!
     * This function is called to go to page 0 on the configuration menu
     */
    'gotoPage0': function(){},
    /*!
     * This function sets up the display elements for the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'init': function(uiStyle,swipe,actionControllers){
        var cont,views=[];
        style = uiStyle;
        window = Titanium.UI.createWindow(uiStyle._extend(uiStyle.window, {
            title:'Configuration: Datalogging'
        }));
        cont = Titanium.UI.createView(uiStyle.containerCanvas);
        window.add(cont);
        window.addEventListener('swipe',swipe);
        
        //title block
        views[0] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '1%',height: '15%',width: '98%'}));
        cont.add(views[0]);
        views[0].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textMedium,{text:"Datalogging Pg. 3",width:'100%',height:'100%',left: '0',top: '0'})));
        views[0].children[0].addEventListener('click',module.exports.gotoPage0);
        
        //data block
        views[1] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '17%',height: '82%',width: '98%'}));
        cont.add(views[1]);
        
        //clear logs + totals
        activeCtrls["logClear"] = new actionControllers.CommandElement(uiStyle._extend(uiStyle.stdButton,{title:"CLEAR LOGS",width:'40%',top: '60%',left: '4%'}),function(id){
            sendBack = {
            	'cmd':{
            		'clearLogs':id
            	}
            };
        },false);
        views[1].add(activeCtrls["logClear"].getObject());
        
        activeCtrls["totalClear"] = new actionControllers.CommandElement(uiStyle._extend(uiStyle.stdButton,{title:"CLEAR TOTALS",width:'40%',top: '80%',left: '4%'}),function(id){
            sendBack = {
            	'cmd':{
            		'clearTotals':id
            	}
            };
        },false);
        views[1].add(activeCtrls["totalClear"].getObject());
        
        //set date time
        activeCtrls["setTime"] = new actionControllers.CommandElement(uiStyle._extend(uiStyle.stdButton,{title:"SET TIME",width:'40%',top: '5%',left: '55%'}),function(id){
            var time = new Date();
            sendBack = {
            	'cmd':{
            		'settime':[time.getFullYear()+'.'+(time.getMonth()+1)+'.'+time.getDate()+'-'+time.getHours()+':'+time.getMinutes()+':'+time.getSeconds(),id]
            	}
            };
        },false);
        views[1].add(activeCtrls["setTime"].getObject());
        
        //Datalog Key
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textMediumUL,{text:"DATALOG KEY",width:'40%',height:55,left: '55%',top: '60%'})));
        activeCtrls['datakey'] = new actionControllers.TextEntry(uiStyle._extend(uiStyle.stdButton,{title:"12345",width:'30%',top: '78%',left: '60%'}),function(toSend){
            sendBack = {
            	'cfg':{
            		'dl':{
            			'0':toSend
            		}
            	}
            };
        });
        views[1].add(activeCtrls['datakey'].getObject());
    },
    /*!
     * This function opens the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'open': function(){
        Ti.API.log('opening');
        Ti.API.log(window);
        window.open();
    },
    /*!
     * This function closes the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'close': function(){
        window.close();
    },
    /*!
     * This function updates the active controls on the current window view
     * with new data pushed from the stack.
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @param data JSON data object
     */
    'update': function(data){
        if(!data || !data.s.cfg.dl){
            return;
        }
        activeCtrls['datakey'].value(data.s.cfg.dl[0]);
        activeCtrls["logClear"].value(data.s.cfg.cmd);
        activeCtrls["totalClear"].value(data.s.cfg.cmd);
        activeCtrls["setTime"].value(data.s.cfg.cmd);
    },
    /*!
     * This function gets an object of data to send back to the server
     * based on any user requested actions
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @return object of data
     */
    'getDataTx': function(){
        var temp = sendBack;
        sendBack = {};
        return temp;
    }
    
};