/*!
 * @file 4-datalogging.js
 *
 * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
 * @note Designed with Titanium for iOS and Android devices
 * @note This file contains propritary information
 * @copyright 2014 Riverside MFG LLC
 * @section DESCRIPTION
 *
 * This source file contains the class to draw/update window: CFG 4-datalogging
 */

var window;                /*!< Window object for self */
var activeCtrls = {};    /*!< Controls on window object */
var sendBack = {};        /*!< Object which contains commands to send back to server */

module.exports = {
    /*!
     * This flag determins if the current window should be skipped in the rotation of windows
     */
    'skip': false,
    /*!
     * This is the ID of the page
     */
    'id':'cfg.dl2',
    /*!
     * This function is called to switch to normal mode and should be remapped by the WindowManager
     */
    'switchToNormal': function(){},
    /*!
     * This function is called to go to page 0 on the configuration menu
     */
    'gotoPage0': function(){},
    /*!
     * This function sets up the display elements for the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'init': function(uiStyle,swipe,actionControllers){
        var cont,views=[];
        style = uiStyle;
        window = Titanium.UI.createWindow(uiStyle._extend(uiStyle.window, {
            title:'Configuration: Datalogging'
        }));
        cont = Titanium.UI.createView(uiStyle.containerCanvas);
        window.add(cont);
        window.addEventListener('swipe',swipe);
        
        //title block
        views[0] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '1%',height: '15%',width: '98%'}));
        cont.add(views[0]);
        views[0].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textMedium,{text:"Datalogging Pg. 4",width:'100%',height:'100%',left: '0',top: '0'})));
        views[0].children[0].addEventListener('click',module.exports.gotoPage0);
        
        //data block
        views[1] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '17%',height: '82%',width: '98%'}));
        cont.add(views[1]);
        
        //titles
        views[1].add(Titanium.UI.createView({width : 6, left : '36%', height : '100%', backgroundColor: '#009933', top : '0'}));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Time Interval",width:'35%',height:'16%',left: '0%',top: '0',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Log Clear",width:'35%',height:'16%',left: '0%',top: '16%',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Datalogging Servers",width:'35%',height:'16%',left: '0%',top: '32%',textAlign: 'right'})));
        
        //controls
        activeCtrls["timeInt"] = new actionControllers.ToggleButton(uiStyle._extend(uiStyle.stdButton,{title:"10",width:250,top: '2%',left:'40%'}),function(toSend){
            sendBack = {
            	'cfg':{
            		'dl':{
            			'1':toSend
            		}
            	}
            };
        },[{val:0,text:'10 Sec'},{val:1,text:'30 Sec'},{val:2,text:'60 Sec'},{val:3,text:'90 Sec'},{val:4,text:'120 Sec'}]);
        activeCtrls["timeInt"].value(0);
        views[1].add(activeCtrls["timeInt"].getObject());
        
        activeCtrls["logClear"] = new actionControllers.ToggleButton(uiStyle._extend(uiStyle.stdButton,{title:"10",width:250,top: '18%',left:'40%'}),function(toSend){
        	sendBack = {
            	'cfg':{
            		'dl':{
            			'2':toSend
            		}
            	}
            };
        },[{val:0,text:'AUTO'},{val:1,text:'DAILY'},{val:2,text:'NEVER'}]);
        activeCtrls["logClear"].value(0);
        views[1].add(activeCtrls["logClear"].getObject());
        
        activeCtrls['server1'] = new actionControllers.TextEntry(uiStyle._extend(uiStyle.stdButton,{title:"1",width:250,top: '34%',left: '40%'}),function(toSend){
        	sendBack = {
            	'cfg':{
            		'dl':{
            			'3':toSend
            		}
            	}
            };
        });
        views[1].add(activeCtrls['server1'].getObject());

        activeCtrls['server2'] = new actionControllers.TextEntry(uiStyle._extend(uiStyle.stdButton,{title:"1",width:250,top: '50%',left: '40%'}),function(toSend){
        	sendBack = {
            	'cfg':{
            		'dl':{
            			'4':toSend
            		}
            	}
            };
        });
        views[1].add(activeCtrls['server2'].getObject());
        
        activeCtrls['server3'] = new actionControllers.TextEntry(uiStyle._extend(uiStyle.stdButton,{title:"1",width:250,top: '66%',left: '40%'}),function(toSend){
            sendBack = {
            	'cfg':{
            		'dl':{
            			'5':toSend
            		}
            	}
            };
        });
        views[1].add(activeCtrls['server3'].getObject());
    },
    /*!
     * This function opens the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'open': function(){
        Ti.API.log('opening');
        Ti.API.log(window);
        window.open();
    },
    /*!
     * This function closes the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'close': function(){
        window.close();
    },
    /*!
     * This function updates the active controls on the current window view
     * with new data pushed from the stack.
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @param data JSON data object
     */
    'update': function(data){
        if(!data || !data.s.cfg.dl){
            return;
        }
        activeCtrls["timeInt"].value(data.s.cfg.dl[1]);
        activeCtrls["logClear"].value(data.s.cfg.dl[2]);
        activeCtrls["server1"].value(data.s.cfg.dl[3]);
        activeCtrls["server2"].value(data.s.cfg.dl[4]);
        activeCtrls["server3"].value(data.s.cfg.dl[5]);
    },
    /*!
     * This function gets an object of data to send back to the server
     * based on any user requested actions
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @return object of data
     */
    'getDataTx': function(){
        var temp = sendBack;
        sendBack = {};
        return temp;
    }
    
};