/*!
 * @file 4-datalogging.js
 *
 * @author Kevin Wijesekera <kwijesekera@munciepower.com>
 * @note Designed with Titanium for iOS and Android devices
 * @note This file contains propritary information
 * @copyright 2015 Riverside MFG LLC
 * @section DESCRIPTION
 *
 * This source file contains the class to draw/update window: CFG 4-datalogging
 */

var window;                /*!< Window object for self */
var activeCtrls = {};    /*!< Controls on window object */
var sendBack = {};        /*!< Object which contains commands to send back to server */
var wifiData = {};
var pageNumber = 0;
var maxPages = 0;
var actionControllers;

module.exports = {
    /*!
     * This flag determins if the current window should be skipped in the rotation of windows
     */
    'skip': false,
    /*!
     * This is the ID of the page
     */
    'id':'cfg.wifi',
    /*!
     * This function is called to switch to normal mode and should be remapped by the WindowManager
     */
    'switchToNormal': function(){},
    /*!
     * This function is called to go to page 0 on the configuration menu
     */
    'gotoPage0': function(){},
    /*!
     * This function sets up the display elements for the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@munciepower.com>
     * @date 11/17/2015
     * @note Designed with Titanium API ver. 4.x
     */
    'init': function(uiStyle,swipe,ac){
        var cont,views=[];
        style = uiStyle;
        actionControllers = ac;
        window = Titanium.UI.createWindow(uiStyle._extend(uiStyle.window, {
            title:'Configuration: WiFi'
        }));
        cont = Titanium.UI.createView(uiStyle.containerCanvas);
        window.add(cont);
        window.addEventListener('swipe',swipe);
        
        //title block
        views[0] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '1%',height: '15%',width: '98%'}));
        cont.add(views[0]);
        views[0].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textMedium,{text:"WiFi Pg. 5",width:'100%',height:'100%',left: '0',top: '0'})));
        views[0].children[0].addEventListener('click',module.exports.gotoPage0);
        
        //data block
        views[1] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '17%',height: '82%',width: '98%'}));
        cont.add(views[1]);
        
        //SSID labels
        activeCtrls['network1'] = new actionControllers.WifiEdit(uiStyle._extend(uiStyle.textMedium,{text:"",width:'70%',height:'16%',left: '0%',top: '0',textAlign: Ti.UI.TEXT_ALIGNMENT_CENTER}),function(act,toSend){
        	sendBack['cmd']= {};
        	sendBack['cmd'][act]= toSend;
        });
        views[1].add(activeCtrls['network1'].getObject());

        activeCtrls['network2'] = new actionControllers.WifiEdit(uiStyle._extend(uiStyle.textMedium,{text:"",width:'70%',height:'16%',left: '0%',top: '16%',textAlign: Ti.UI.TEXT_ALIGNMENT_CENTER}),function(act,toSend){
        	sendBack['cmd']= {};
        	sendBack['cmd'][act]= toSend;
        });
        views[1].add(activeCtrls['network2'].getObject());

        activeCtrls['network3'] = new actionControllers.WifiEdit(uiStyle._extend(uiStyle.textMedium,{text:"",width:'70%',height:'16%',left: '0%',top: '32%',textAlign: Ti.UI.TEXT_ALIGNMENT_CENTER}),function(act,toSend){
        	sendBack['cmd']= {};
        	sendBack['cmd'][act]= toSend;
        });
        views[1].add(activeCtrls['network3'].getObject());

        activeCtrls['network4'] = new actionControllers.WifiEdit(uiStyle._extend(uiStyle.textMedium,{text:"",width:'70%',height:'16%',left: '0%',top: '48%',textAlign: Ti.UI.TEXT_ALIGNMENT_CENTER}),function(act,toSend){
        	sendBack['cmd']= {};
        	sendBack['cmd'][act]= toSend;
        });
        views[1].add(activeCtrls['network4'].getObject());

 		activeCtrls['network5'] = new actionControllers.WifiEdit(uiStyle._extend(uiStyle.textMedium,{text:"",width:'70%',height:'16%',left: '0%',top: '64%',textAlign: Ti.UI.TEXT_ALIGNMENT_CENTER}),function(act,toSend){
        	sendBack['cmd']= {};
        	sendBack['cmd'][act]= toSend;
        });
        views[1].add(activeCtrls['network5'].getObject());
        
        //Direction buttons
        activeCtrls['up1'] = new actionControllers.CommandElement(uiStyle._extend(uiStyle.stdButton,{title:"Up",width:150,left:'70%',top: '2%'}),function(id){
            sendBack['cmd'] = {'wifi.up':[activeCtrls['network1'].value(),id]};
        },false);
        views[1].add(activeCtrls['up1'].getObject());

		activeCtrls['up2'] = new actionControllers.CommandElement(uiStyle._extend(uiStyle.stdButton,{title:"Up",width:150,left:'70%',top: '18%'}),function(id){
            sendBack['cmd'] = {'wifi.up':[activeCtrls['network2'].value(),id]};
        },false);
        views[1].add(activeCtrls['up2'].getObject());

        activeCtrls['up3'] = new actionControllers.CommandElement(uiStyle._extend(uiStyle.stdButton,{title:"Up",width:150,left:'70%',top: '34%'}),function(id){
            sendBack['cmd'] = {'wifi.up':[activeCtrls['network3'].value(),id]};
        },false);
        views[1].add(activeCtrls['up3'].getObject());
 
        activeCtrls['up4'] = new actionControllers.CommandElement(uiStyle._extend(uiStyle.stdButton,{title:"Up",width:150,left:'70%',top: '50%'}),function(id){
            sendBack['cmd'] = {'wifi.up':[activeCtrls['network4'].value(),id]};
        },false);
        views[1].add(activeCtrls['up4'].getObject());

        
        //Prev
        temp = Titanium.UI.createButton(uiStyle._extend(uiStyle.stdButton,{title:"Previous",width:'40%',top: '80%',left: '4%'}));
        temp.addEventListener('click', function(e){
			if(pageNumber > 0){
				pageNumber--;
			}
        });
        views[1].add(temp);
        
        //Next
        temp = Titanium.UI.createButton(uiStyle._extend(uiStyle.stdButton,{title:"Next",width:'40%',top: '80%',left: '55%'}));
        temp.addEventListener('click', function(e){
			if(pageNumber < maxPages){
				pageNumber++;
			}
        });
        views[1].add(temp);
    
    },
    /*!
     * This function opens the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@munciepower.com>
     * @date 11/17/2015
     * @note Designed with Titanium API ver. 4.x
     */
    'open': function(){
        window.open();
    },
    /*!
     * This function closes the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@munciepower.com>
     * @date 11/17/2015
     * @note Designed with Titanium API ver. 4.x
     */
    'close': function(){
        window.close();
    },
    /*!
     * This function updates the active controls on the current window view
     * with new data pushed from the stack.
     *
     * @author Kevin Wijesekera <kwijesekera@munciepower.com>
     * @date 11/17/2015
     * @note Designed with Titanium API ver. 4.x
     * 
     * @param data JSON data object
     */
    'update': function(data){
    	var start,end,i=1;
    	
        if(!data || !data.s.wifi){
            return;
        }
        
        activeCtrls['up1'].value(data.s.cfg.cmd);
        activeCtrls['up2'].value(data.s.cfg.cmd);
        activeCtrls['up3'].value(data.s.cfg.cmd);
        activeCtrls['up4'].value(data.s.cfg.cmd);
        
        wifiData = data.s.wifi.c;
        maxPages = wifiData.length;
        if(pageNumber >= maxPages){
        	pageNumber = maxPages-1;
        }
        start = pageNumber * 4;
        end = start + 4;
        
        for(;start < end;start++){
        	var ap = wifiData[start];
        	if(ap){
        		activeCtrls['network'+i].value(ap,data.s.cfg.cmd);
        	}
        	else{
        		activeCtrls['network'+i].value(null,data.s.cfg.cmd);
        	}
        	i++;
        }
        activeCtrls['network5'].value('[Add Network]',data.s.cfg.cmd);
    },
    /*!
     * This function gets an object of data to send back to the server
     * based on any user requested actions
     *
     * @author Kevin Wijesekera <kwijesekera@munciepower.com>
     * @date 11/17/2015
     * @note Designed with Titanium API ver. 4.x
     * 
     * @return object of data
     */
    'getDataTx': function(){
        var temp = sendBack;
        sendBack = {};
        return temp;
    }
    
};