/*!
 * @file 6-global.js
 *
 * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
 * @note Designed with Titanium for iOS and Android devices
 * @note This file contains propritary information
 * @copyright 2014 Riverside MFG LLC
 * @section DESCRIPTION
 *
 * This source file contains the class to draw/update window: CFG 6-global
 */

var window;                /*!< Window object for self */
var activeCtrls = {};    /*!< Controls on window object */
var sendBack = {};        /*!< Object which contains commands to send back to server */
var style;                /*!< UI Style Wrapper */

module.exports = {
    /*!
     * This flag determins if the current window should be skipped in the rotation of windows
     */
    'skip': false,
    /*!
     * This is the ID of the page
     */
    'id':'cfg.glo1',
    /*!
     * This function is called to switch to normal mode and should be remapped by the WindowManager
     */
    'switchToNormal': function(){},
    /*!
     * This function is called to go to page 0 on the configuration menu
     */
    'gotoPage0': function(){},
    /*!
     * This function sets up the display elements for the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'init': function(uiStyle,swipe,actionControllers){
        var cont,views=[];
        style = uiStyle;
        window = Titanium.UI.createWindow(uiStyle._extend(uiStyle.window, {
            title:'Configuration: Global Settings'
        }));
        cont = Titanium.UI.createView(uiStyle.containerCanvas);
        window.add(cont);
        window.addEventListener('swipe',swipe);
        
        //title block
        views[0] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '1%',height: '15%',width: '98%'}));
        cont.add(views[0]);
        views[0].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textMedium,{text:"Global Settings Pg. 6",width:'100%',height:'100%',left: '0',top: '0'})));
        views[0].children[0].addEventListener('click',module.exports.gotoPage0);
        
        //data block
        views[1] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '17%',height: '82%',width: '98%'}));
        cont.add(views[1]);
        
        //titles
        views[1].add(Titanium.UI.createView({width : 6, left : '36%', height : '100%', backgroundColor: '#009933', top : '0'}));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Pump Type",width:'35%',height:'16%',left: '0%',top: '0',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"PWM Freq G1",width:'35%',height:'16%',left: '0%',top: '16%',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"PWM Freq G2",width:'35%',height:'16%',left: '0%',top: '32%',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Main Relief Press",width:'35%',height:'16%',left: '0%',top: '48%',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Transducer",width:'35%',height:'16%',left: '0%',top: '64%',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Main Relief Ramp",width:'35%',height:'16%',left: '0%',top: '80%',textAlign: 'right'})));
        
        //controls
        activeCtrls["pumpType"] = new actionControllers.ToggleButton(uiStyle._extend(uiStyle.stdButton,{title:"10",width:250,top: '2%',left:'40%'}),function(toSend){
            sendBack = {
            	'cfg':{
            		'glo':{
            			'0':toSend
            		}
            	}
            };
        },[{val:0,text:'Piston Pump'},{val:1,text:'Gear Pump'},{val:2,text:'Disabled'}]);
        activeCtrls["pumpType"].value(0);
        views[1].add(activeCtrls["pumpType"].getObject());
        
        activeCtrls["pwmG1"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"10Hz",width:250,left:'40%',top: '18%'}),function(toSend){
            sendBack = {
            	'cfg':{
            		'glo':{
            			'3':toSend
            		}
            	}
            };
        },false,{min:5,max:30,inc:1,multi:10,units:' Hz'});
        views[1].add(activeCtrls["pwmG1"].getObject());
        
        activeCtrls["pwmG2"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"10Hz",width:250,left:'40%',top: '34%'}),function(toSend){
            sendBack = {
            	'cfg':{
            		'glo':{
            			'4':toSend
            		}
            	}
            };
        },false,{min:5,max:30,inc:1,multi:10,units:' Hz'});
        views[1].add(activeCtrls["pwmG2"].getObject());
        
        activeCtrls["rPressure"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"10Hz",width:250,left:'40%',top: '50%'}),function(toSend){
            sendBack = {
            	'cfg':{
            		'glo':{
            			'1':toSend
            		}
            	}
            };
        },false,{min:30,max:60,inc:2,multi:50,units:' PSI'});
        views[1].add(activeCtrls["rPressure"].getObject());    
        
        activeCtrls['pressure'] = Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Pump: 0000 PSI / Load: 0000 PSI",height:'16%',left: '38%',top: '66%',textAlign: 'left'}));
        views[1].add(activeCtrls['pressure']);
        activeCtrls["ramp"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"10Hz",width:250,left:'40%',top: '82%'}),function(toSend){
            sendBack = {
            	'cfg':{
            		'glo':{
            			'2':toSend
            		}
            	}
            };
        },false,{min:0,max:10,inc:1,multi:0.05,units:' Sec'});
        views[1].add(activeCtrls["ramp"].getObject());    
    },
    /*!
     * This function opens the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'open': function(){
        Ti.API.log('opening');
        Ti.API.log(window);
        window.open();
    },
    /*!
     * This function closes the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'close': function(){
        window.close();
    },
    /*!
     * This function updates the active controls on the current window view
     * with new data pushed from the stack.
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @param data JSON data object
     */
    'update': function(data){
        if(!data || !data.s.cfg.glo){
            return;
        }
        activeCtrls["pumpType"].value(data.s.cfg.glo[0]);
        activeCtrls["rPressure"].value(data.s.cfg.glo[1]);
        activeCtrls["ramp"].value(data.s.cfg.glo[2]);
        activeCtrls["pwmG1"].value(data.s.cfg.glo[3]);
        activeCtrls["pwmG2"].value(data.s.cfg.glo[4]);
        activeCtrls['pressure'].text = 'Pump: '+style._numberToString(data.d[0].gui[15],0,4) + ' PSI / Load: '+style._numberToString(data.d[0].gui[16],0,4)+' PSI';
    },
    /*!
     * This function gets an object of data to send back to the server
     * based on any user requested actions
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @return object of data
     */
    'getDataTx': function(){
        var temp = sendBack;
        sendBack = {};
        return temp;
    }
    
};