/*!
 * @file 8-spreader.js
 *
 * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
 * @note Designed with Titanium for iOS and Android devices
 * @note This file contains propritary information
 * @copyright 2014 Riverside MFG LLC
 * @section DESCRIPTION
 *
 * This source file contains the class to draw/update window: CFG 8-spreader
 */

var window;                /*!< Window object for self */
var activeCtrls = {};    /*!< Controls on window object */
var sendBack = {};        /*!< Object which contains commands to send back to server */
var style;                /*!< UI Style Wrapper */

module.exports = {
    /*!
     * This flag determins if the current window should be skipped in the rotation of windows
     */
    'skip': false,
    /*!
     * This is the ID of the page
     */
    'id':'cfg.sprd1',
    /*!
     * This function is called to go to page 0 on the configuration menu
     */
    'gotoPage0': function(){},
    /*!
     * This function sets up the display elements for the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'init': function(uiStyle,swipe,actionControllers){
        var cont,views=[];
        style = uiStyle;
        window = Titanium.UI.createWindow(uiStyle._extend(uiStyle.window, {
            title:'Configuration: Spreader Settings'
        }));
        cont = Titanium.UI.createView(uiStyle.containerCanvas);
        window.add(cont);
        window.addEventListener('swipe',swipe);
        
        //title block
        views[0] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '1%',height: '15%',width: '98%'}));
        cont.add(views[0]);
        views[0].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textMedium,{text:"Spreader Pg. 8",width:'100%',height:'100%',left: '0',top: '0'})));
        views[0].children[0].addEventListener('click',module.exports.gotoPage0);
        
        //data block
        views[1] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '17%',height: '82%',width: '98%'}));
        cont.add(views[1]);
        
        //titles
        views[1].add(Titanium.UI.createView({width : 6, left : '36%', height : '100%', backgroundColor: '#009933', top : '0'}));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Auger Speed",width:'35%',height:'16%',left: '0%',top: '0',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Spinner Speed",width:'35%',height:'16%',left: '0%',top: '16%',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Control Loop",width:'35%',height:'16%',left: '0%',top: '32%',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Manual Mode",width:'35%',height:'16%',left: '0%',top: '48%',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"0 MPH Spinner",width:'35%',height:'16%',left: '0%',top: '64%',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Retain Settings",width:'35%',height:'16%',left: '0%',top: '80%',textAlign: 'right'})));
        
        //controls
        activeCtrls["auger"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"10Hz",width:250,left:'40%',top: '2%'}),function(toSend){
            sendBack = {
            	'cfg':{
            		'sprdm':{
            			'0':toSend
            		}
            	}
            };
        },true,{min:0,max:100,inc:1,multi:1,units:'%'});
        views[1].add(activeCtrls["auger"].getObject());
        
        activeCtrls["spinner"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"10Hz",width:250,left:'40%',top: '18%'}),function(toSend){
            sendBack = {
            	'cfg':{
            		'sprdm':{
            			'1':toSend
            		}
            	}
            };
        },true,{min:0,max:100,inc:1,multi:1,units:'%'});
        views[1].add(activeCtrls["spinner"].getObject());
        
        
        activeCtrls["cloop"] = new actionControllers.ToggleButton(uiStyle._extend(uiStyle.stdButton,{title:"10",width:250,top: '34%',left:'40%'}),function(toSend){
            sendBack = {
            	'cfg':{
            		'sprdm':{
            			'2':toSend
            		}
            	}
            };
        },[{val:false,text:'Open Loop'},{val:true,text:'Closed Loop'}]);
        activeCtrls["cloop"].value(0);
        views[1].add(activeCtrls["cloop"].getObject());
        
        activeCtrls["mmode"] = new actionControllers.ToggleButton(uiStyle._extend(uiStyle.stdButton,{title:"10",width:250,top: '50%',left:'40%'}),function(toSend){
            sendBack = {
            	'cfg':{
            		'sprdm':{
            			'3':toSend
            		}
            	}
            };
        },[{val:false,text:'Manual Disabled'},{val:true,text:'Manual Enabled'}]);
        activeCtrls["mmode"].value(0);
        views[1].add(activeCtrls["mmode"].getObject());
        
        activeCtrls["spin0"] = new actionControllers.ToggleButton(uiStyle._extend(uiStyle.stdButton,{title:"10",width:250,top: '66%',left:'40%'}),function(toSend){
        	sendBack = {
            	'cfg':{
            		'sprdm':{
            			'4':toSend
            		}
            	}
            };
        },[{val:false,text:'Spinner On'},{val:true,text:'Spinner Off'}]);
        activeCtrls["spin0"].value(0);
        views[1].add(activeCtrls["spin0"].getObject());
        
        activeCtrls["retain"] = new actionControllers.ToggleButton(uiStyle._extend(uiStyle.stdButton,{title:"10",width:250,top: '82%',left:'40%'}),function(toSend){
        	sendBack = {
            	'cfg':{
            		'sprdm':{
            			'6':toSend
            		}
            	}
            };
        },[{val:false,text:'Off'},{val:true,text:'On'}]);
        activeCtrls["retain"].value(0);
        views[1].add(activeCtrls["retain"].getObject());
    },
    /*!
     * This function opens the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'open': function(){
        Ti.API.log('opening');
        Ti.API.log(window);
        window.open();
    },
    /*!
     * This function closes the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'close': function(){
        window.close();
    },
    /*!
     * This function updates the active controls on the current window view
     * with new data pushed from the stack.
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @param data JSON data object
     */
    'update': function(data){
        if(!data || !data.s.cfg.sprdm){
            return;
        }
        activeCtrls["auger"].value(data.s.cfg.sprdm[0]);
        activeCtrls["spinner"].value(data.s.cfg.sprdm[1]);
        activeCtrls["cloop"].value(data.s.cfg.sprdm[2]);
        activeCtrls["mmode"].value(data.s.cfg.sprdm[3]);
        activeCtrls["spin0"].value(data.s.cfg.sprdm[4]);
        activeCtrls["retain"].value(data.s.cfg.sprdm[6]);
    },
    /*!
     * This function gets an object of data to send back to the server
     * based on any user requested actions
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @return object of data
     */
    'getDataTx': function(){
        var temp = sendBack;
        sendBack = {};
        return temp;
    }
    
};