/*!
 * @file 9-spreader.js
 *
 * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
 * @note Designed with Titanium for iOS and Android devices
 * @note This file contains propritary information
 * @copyright 2014 Riverside MFG LLC
 * @section DESCRIPTION
 *
 * This source file contains the class to draw/update window: CFG 9-spreader
 */

var window;                /*!< Window object for self */
var activeCtrls = {};    /*!< Controls on window object */
var sendBack = {};        /*!< Object which contains commands to send back to server */
var style;                /*!< UI Style Wrapper */

module.exports = {
    /*!
     * This flag determins if the current window should be skipped in the rotation of windows
     */
    'skip': false,
    /*!
     * This is the ID of the page
     */
    'id':'cfg.sprd2',
    /*!
     * This function is called to switch to normal mode and should be remapped by the WindowManager
     */
    'switchToNormal': function(){},
    /*!
     * This function is called to go to page 0 on the configuration menu
     */
    'gotoPage0': function(){},
    /*!
     * This function is called to switch the skip flag of the next page
     */
    'skipNextPage': function(skip){},
    /*!
     * This function sets up the display elements for the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'init': function(uiStyle,swipe,actionControllers){
        var cont,views=[];
        style = uiStyle;
        window = Titanium.UI.createWindow(uiStyle._extend(uiStyle.window, {
            title:'Configuration: Spreader Settings'
        }));
        cont = Titanium.UI.createView(uiStyle.containerCanvas);
        window.add(cont);
        window.addEventListener('swipe',swipe);
        
        //title block
        views[0] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '1%',height: '15%',width: '98%'}));
        cont.add(views[0]);
        views[0].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textMedium,{text:"Spreader Pg. 9",width:'100%',height:'100%',left: '0',top: '0'})));
        views[0].children[0].addEventListener('click',module.exports.gotoPage0);
        
        //data block
        views[1] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '17%',height: '82%',width: '98%'}));
        cont.add(views[1]);
        
        //titles
        views[1].add(Titanium.UI.createView({width : 6, left : '36%', height : '100%', backgroundColor: '#009933', top : '0'}));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Blast Level",width:'35%',height:'16%',left: '0%',top: '0',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Blast Duration",width:'35%',height:'16%',left: '0%',top: '16%',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Take-Off Timer",width:'35%',height:'16%',left: '0%',top: '32%',textAlign: 'right'})));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Preset Mode",width:'35%',height:'16%',left: '0%',top: '48%',textAlign: 'right'})));
        activeCtrls['lbl-presetLow'] = Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Preset Low",width:'35%',height:'16%',left: '0%',top: '64%',textAlign: 'right'}));
        activeCtrls['lbl-presetHigh'] = Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"Preset High",width:'35%',height:'16%',left: '0%',top: '80%',textAlign: 'right'}));
        views[1].add(activeCtrls['lbl-presetLow']);
        views[1].add(activeCtrls['lbl-presetHigh']);
        
        //controls
        activeCtrls["blastL"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"10Hz",width:250,left:'40%',top: '2%'}),function(toSend){
        	sendBack = {
            	'cfg':{
            		'sprdm':{
            			'7':toSend
            		}
            	}
            };
        },false,{min:50,max:100,inc:1,multi:1,units:'%'});
        views[1].add(activeCtrls["blastL"].getObject());
        
        activeCtrls["blastD"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"10Hz",width:250,left:'40%',top: '18%'}),function(toSend){
        	sendBack = {
            	'cfg':{
            		'sprdm':{
            			'8':toSend
            		}
            	}
            };
        },false,{min:0,max:255,inc:1,multi:0.1,units:' Sec'});
        views[1].add(activeCtrls["blastD"].getObject());
        
        activeCtrls["tofft"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"10Hz",width:250,left:'40%',top: '34%'}),function(toSend){
        	sendBack = {
            	'cfg':{
            		'sprdm':{
            			'9':toSend
            		}
            	}
            };
        },false,{min:0,max:50,inc:1,multi:0.1,units:' Sec'});
        views[1].add(activeCtrls["tofft"].getObject());
        
        activeCtrls["pmode"] = new actionControllers.ToggleButton(uiStyle._extend(uiStyle.stdButton,{title:"10",width:250,top: '50%',left:'40%'}),function(toSend){
        	sendBack = {
            	'cfg':{
            		'sprdm':{
            			'5':toSend
            		}
            	}
            };
        },[{val:true,text:'Fixed'},{val:false,text:'Range'}]);
        activeCtrls["pmode"].value(1);
        views[1].add(activeCtrls["pmode"].getObject());
        
        activeCtrls["rangeL"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"10Hz",width:250,left:'40%',top: '66%'}),function(toSend){
        	sendBack = {
            	'cfg':{
            		'sprdm':{
            			'10':{'0':toSend}
            		}
            	}
            };
        },false,{min:0,max:30,inc:1,multi:50,units:' Lbs/Mi'});
        views[1].add(activeCtrls["rangeL"].getObject());
        
        activeCtrls["rangeH"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"10Hz",width:250,left:'40%',top: '82%'}),function(toSend){
        	sendBack = {
            	'cfg':{
            		'sprdm':{
            			'10':{'1':toSend}
            		}
            	}
            };
        },false,{min:0,max:30,inc:1,multi:50,units:' Lbs/Mi'});
        views[1].add(activeCtrls["rangeH"].getObject());
    },
    /*!
     * This function opens the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'open': function(){
        Ti.API.log('opening');
        Ti.API.log(window);
        window.open();
    },
    /*!
     * This function closes the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'close': function(){
        window.close();
    },
    /*!
     * This function updates the active controls on the current window view
     * with new data pushed from the stack.
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @param data JSON data object
     */
    'update': function(data){
        if(data == false){
            return;
        }
        if(data.s.cfg.sprdm[5] == 1){
            activeCtrls['lbl-presetLow'].visible = false;
            activeCtrls['lbl-presetHigh'].visible = false;
            activeCtrls["rangeL"].hide();
            activeCtrls["rangeH"].hide();
            module.exports.skipNextPage(false);
        }
        else{
            activeCtrls['lbl-presetLow'].visible = true;
            activeCtrls['lbl-presetHigh'].visible = true;
            activeCtrls["rangeL"].show();
            activeCtrls["rangeH"].show();
            module.exports.skipNextPage(true);
        }

        //[INFO] :   0,50,0,50,1,1,0,50,0,0,1,1,20,0,0,0,0,0,1
        activeCtrls["blastL"].value(data.s.cfg.sprdm[7]);
        activeCtrls["blastD"].value(data.s.cfg.sprdm[8]);
        activeCtrls["tofft"].value(data.s.cfg.sprdm[9]);
        activeCtrls["pmode"].value(data.s.cfg.sprdm[5]);
        activeCtrls["rangeL"].value(data.s.cfg.sprdm[10][0]);
        activeCtrls["rangeH"].value(data.s.cfg.sprdm[10][1]);
    },
    /*!
     * This function gets an object of data to send back to the server
     * based on any user requested actions
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @return object of data
     */
    'getDataTx': function(){
        var temp = sendBack;
        sendBack = {};
        return temp;
    }
    
};