/*!
 * @file 13-equipment.js
 *
 * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
 * @note Designed with Titanium for iOS and Android devices
 * @note This file contains propritary information
 * @copyright 2014 Riverside MFG LLC
 * @section DESCRIPTION
 *
 * This source file contains the class to draw/update window: CFG 13-equipment
 * 
 * This window handles Pre-Wet, Tow Plow and Xzalt configuration (only one can be active at once)
 */

var sendBack= {};
var activeCtrls = {};
var actionControllers;

module.exports = {
    /*!
     * List of windows associated with the dynamic configuration
     */
    'windows': [],
    /*!
     * Flag indiciating if the dynamic config has been setup
     */
    'setup':false,
    /*!
     * This function is called to go to page 0 on the configuration menu
     */
    'gotoPage0': function(){},
    /*!
     * This function sets up the display elements for the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'init': function(uiStyle,swipe,dataStruct,startPageNo,ac){
        var wIndex = 0;
        //cleanup
        activeCtrls = {};
        module.exports.windows = [];
        actionControllers = ac;
        
        //interate though all config
        for(var group in dataStruct){
        	for(var page in dataStruct[group]){
        		var cont,views=[],top=0;
        		//setup new window
                module.exports.windows[wIndex] = Titanium.UI.createWindow(uiStyle._extend(uiStyle.window, {
                    title:'Configuration: '+group
                }));
                cont = Titanium.UI.createView(uiStyle.containerCanvas);
                module.exports.windows[wIndex].add(cont);
                module.exports.windows[wIndex].addEventListener('swipe',swipe);
                
                //new title block
                views[0] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '1%',height: '15%',width: '98%'}));
                cont.add(views[0]);
                views[0].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textMedium,{text:group+' Pg. '+(startPageNo+wIndex).toString(),width:'100%',height:'100%',left: '0',top: '0'})));
                views[0].children[0].addEventListener('click',module.exports.gotoPage0);
                
                //new data block
                views[1] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '17%',height: '82%',width: '98%'}));
                cont.add(views[1]);
                
        		views[1].add(Titanium.UI.createView({width : 6, left : '36%', height : '100%', backgroundColor: '#009933', top : '0'}));
        		for(var index in dataStruct[group][page]){
        			var item = dataStruct[group][page][index],obj;
        			item[0] = item[0].split('|');
                    views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:group+' | '+item[0][1],width:'35%',height:"15%",left: '0%',top: top.toString()+"%" ,textAlign: 'right'})));
                    obj = setupDynamicConfigElement(group,item[0][0],item[1],top,uiStyle);
                    views[1].add(obj.getObject());
                    top += 16;
        		}
        		
        		wIndex++;
        	}
        }

        setup = true;
    },
    /*!
     * This function updates the active controls on the current window view
     * with new data pushed from the stack.
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @param data JSON data object
     */
    'update': function(data){
        if(!data  || !setup){
            return;
        }
        for(var group in data.s.dcfg){
            for(var funct in data.s.dcfg[group]){
                var id = group+'_'+funct,d=data.s.dcfg[group][funct];
                if(activeCtrls[id+'_flt']){
                	activeCtrls[id+'_flt'].value(d[0]);
                }
                if(activeCtrls[id+'_da']){
                	activeCtrls[id+'_da'].value(d[1]);
                }
                if(activeCtrls[id+'_rel']){
                	activeCtrls[id+'_rel'].value(d[2]);
                }
                if(activeCtrls[id+'_spd']){
                	activeCtrls[id+'_spd'].value(d[3]);
                }
            }
        }
    },
    /*!
     * This function gets an object of data to send back to the server
     * based on any user requested actions
     *
     * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @return object of data
     */
    'getDataTx': function(){
        var temp = sendBack;
        sendBack = {};
        return temp;
    }
};

function setupDynamicConfigElement(gid,fid,type,top,uiStyle){
	var key = gid+'_'+fid;
    switch(parseInt(type)){
    	case 1:
        	key += '_flt';
            activeCtrls[key] = new actionControllers.ToggleButton(uiStyle._extend(uiStyle.stdButton,{title:"10",width:250,'top': (top+2).toString()+'%',left:'40%'}),function(toSend){
                sendBack['dcfg']={};
                sendBack['dcfg'][gid]={};
                sendBack['dcfg'][gid][fid]={'0':toSend};
            },[{val:false,text:'Float Disabled'},{val:true,text:'Float Enabled'}]);
        break;
        case 2:
        	key += '_da';
            activeCtrls[key] = new actionControllers.ToggleButton(uiStyle._extend(uiStyle.stdButton,{title:"10",width:250,'top': (top+2).toString()+'%',left:'40%'}),function(toSend){
                sendBack['dcfg']={};
                sendBack['dcfg'][gid]={};
                sendBack['dcfg'][gid][fid]={'1':toSend};
            },[{val:false,text:'Single Acting'},{val:true,text:'Double Acting'}]);
        break;
        case 3:
        	key += '_rel';
            activeCtrls[key] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"10",width:250,'top': (top+2).toString()+'%',left:'40%'}),function(toSend){
                sendBack['dcfg']={};
                sendBack['dcfg'][gid]={};
                sendBack['dcfg'][gid][fid]={'2':toSend};
            },false,{min:0,max:20,inc:1,multi:50,units:' PSI'});
        break;
        default:
        case 4:
        	key += '_spd';
            activeCtrls[key] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"10",width:250,'top': (top+2).toString()+'%',left:'40%'}),function(toSend){
                sendBack['dcfg']={};
                sendBack['dcfg'][gid]={};
                sendBack['dcfg'][gid][fid]={'3':toSend};
            },true,{min:0,max:100,inc:1,multi:1,units:'%'});
        break;
    };
    return activeCtrls[key];
}
