/*!
 * @file 1-oper.js
 *
 * @author Kevin Wijesekera <kwijesekera@munciepower.com>
 * @note Designed with Titanium for iOS and Android devices
 * @note This file contains propritary information
 * @copyright 2014 Riverside MFG LLC
 * @section DESCRIPTION
 *
 * This source file contains the class to draw/update window: 1-oper
 */

var window;                /*!< Window object for self */
var activeCtrls = {};    /*!< Controls on window object */
var views = {};            /*!< View boxes on window object */
var style;                /*!< UI Style Object */
var sendBack = {};
var init = false;

module.exports = {
    /*!
     * This flag determins if the current window should be skipped in the rotation of windows
     */
    'skip': false,
    /*!
     * This function sets up the display elements for the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@munciepower.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'init': function(uiStyle,swipe,actionControllers){
        var cont;
        style = uiStyle;
        window = Titanium.UI.createWindow(uiStyle._extend(uiStyle.window, {
            title:'Operator Controls'
        }));
        cont = Titanium.UI.createView(uiStyle.containerCanvas);
        window.add(cont);
        window.addEventListener('swipe',swipe);

        //temperatures view
        views['tempBox'] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '1%',height: '36%',width: '25%'}));
        views['tempBox'].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"AIR TEMP",width:'45%',height:'50%',left: '0',top: '0'})));
        views['tempBox'].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"ROAD TEMP",width:'45%',height:'50%',left: '0',top: '50%'})));
        activeCtrls['airTemp']=Titanium.UI.createLabel(uiStyle._extend(uiStyle.textXLarge,{text:" 00",width:'54%',height:'50%',left: '46%',top: '0'}));
        activeCtrls['roadTemp']=Titanium.UI.createLabel(uiStyle._extend(uiStyle.textXLarge,{text:" 00",width:'54%',height:'50%',left: '46%',top: '50%'}));
        views['tempBox'].add(activeCtrls['airTemp']);
        views['tempBox'].add(activeCtrls['roadTemp']);
        cont.add(views['tempBox']);
        
        //controls4 view (anti-ice)
        views['control4'] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '27%',top: '1%',height: '36%',width: '32%'}));
        activeCtrls['control4']=Titanium.UI.createLabel(uiStyle._extend(uiStyle.textXLarge,{text:"OFF",width:'60%',height:'50%',left: '0%',top: '0%'}));
        activeCtrls['control4Units']=Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"GAL/MI",width:'60%',height:'50%',left: '0%',top: '50%'}));
        activeCtrls['mode2']=Titanium.UI.createLabel(uiStyle._extend(uiStyle.textButtonGreen,{text:"AUTO",layout:'vertical',width:'60%',height:'40%',left: '50%',top: '30%'}));
        views['control4'].add(activeCtrls['control4']);
        views['control4'].add(activeCtrls['control4Units']);
        views['control4'].add(activeCtrls['mode2']);
        cont.add(views['control4']);
        activeCtrls['mode2'].transform = Ti.UI.create2DMatrix({rotate: 90});

        //totals view
        views['totals'] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '27%',top: '1%',height: '36%',width: '32%'}));
        views['totals'].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"TOTALS",width:'100%',height:'20%',left: '0',top: '0'})));
        activeCtrls['prodTotal'] = new actionControllers.CommandElement(uiStyle._extend(uiStyle.textMedium,{text:"0000000",width:'70%',height:'40%',left: '0%',top: '20%'}),function(id){
            sendBack['cmd'] = {'clearProdM':id};
        },true);
        activeCtrls['liqTotal'] = new actionControllers.CommandElement(uiStyle._extend(uiStyle.textMedium,{text:"0000000",width:'70%',height:'40%',left: '0%',top: '60%'}),function(id){
            sendBack['cmd'] = {'clearLiqM':id};
        },true);
        views['totals'].add(activeCtrls['prodTotal'].getObject());
        views['totals'].add(activeCtrls['liqTotal'].getObject());
        views['totals'].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"LBS",width:'30%',height:'40%',left: '70%',top: '20%'})));
        views['totals'].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"GALS",width:'30%',height:'40%',left: '70%',top: '60%'})));
        cont.add(views['totals']);

        
        //joystick view
        views['joystick'] = Titanium.UI.createView(uiStyle._extend(uiStyle.whiteCont,{left: '60%',top: '1%',height: '10%',width: '13%'}));
        activeCtrls['joystick']=Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{color:'#FF0000',text:"PLOW",width:'100%',height:'100%',left: '0%',top: '0%'}));
        views['joystick'].add(activeCtrls['joystick']);
        cont.add(views['joystick']);
        //wifi view
        views['wifi'] = Titanium.UI.createView(uiStyle._extend(uiStyle.whiteCont,{left: '60%',top: '12%',height: '24%',width: '13%'}));
        cont.add(views['wifi']);
        
        //pressures view
        views['pressure'] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '74%',top: '1%',height: '36%',width: '25%'}));
        views['pressure'].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"PUMP PSI",width:'45%',height:'50%',left: '0',top: '0'})));
        views['pressure'].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"LOAD PSI",width:'45%',height:'50%',left: '0',top: '50%'})));
        activeCtrls['pumpPress']=Titanium.UI.createLabel(uiStyle._extend(uiStyle.textMedium,{text:"0000",width:'55%',height:'50%',left: '46%',top: '0'}));
        activeCtrls['loadPress']=Titanium.UI.createLabel(uiStyle._extend(uiStyle.textMedium,{text:"0000",width:'55%',height:'50%',left: '46%',top: '50%'}));
        views['pressure'].add(activeCtrls['pumpPress']);
        views['pressure'].add(activeCtrls['loadPress']);
        cont.add(views['pressure']);
        
        //alerts view
        views['alerts'] = Titanium.UI.createView(uiStyle._extend(uiStyle.whiteCont,{left: '1%',top: '41%',height: '19%',width: '98%'}));
        activeCtrls['msg']=Titanium.UI.createLabel(uiStyle._extend(uiStyle.textMedium,{text:'Alert',color:'#009933',text:"",width:'85%',height:'100%',left: '0%',top: '0%'}));
        activeCtrls['msg-btn'] = new actionControllers.CommandElement(uiStyle._extend(uiStyle.stdButton,{title:"OK",width:'14%',height:'80%',left: '85%',top: '10%'}),function(id){
            sendBack['cmd'] = {'clearAlert':id};
        },false);
        views['alerts'].add(activeCtrls['msg']);
        views['alerts'].add(activeCtrls['msg-btn'].getObject());
        cont.add(views['alerts']);
        
        //anti ice booms
        views['booms'] = Titanium.UI.createView({left: '0%',top: '63%',height: '36%',width: '100%'});
        activeCtrls['leftBoom'] = Titanium.UI.createLabel(uiStyle._extend(uiStyle.textButtonGreenLarge,{text:"Left Boom",width:'20%',height:'80%',left: '10%',top: '1%'}));
        activeCtrls['centerBoom'] = Titanium.UI.createLabel(uiStyle._extend(uiStyle.textButtonGreenLarge,{text:"Center Boom",width:'20%',height:'80%',left: '40%',top: '1%'}));
        activeCtrls['rightBoom'] = Titanium.UI.createLabel(uiStyle._extend(uiStyle.textButtonGreenLarge,{text:"Right Boom",width:'20%',height:'80%',left: '70%',top: '1%'}));
        views['booms'].add(activeCtrls['leftBoom']);
        views['booms'].add(activeCtrls['centerBoom']);
        views['booms'].add(activeCtrls['rightBoom']);
        cont.add(views['booms']);
        
        //control1 view
        views['control1'] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '63%',height: '36%',width: '30%'}));
        activeCtrls['control1']=Titanium.UI.createLabel(uiStyle._extend(uiStyle.textXLarge,{text:"OFF",width:'60%',height:'50%',left: '0%',top: '0%'}));
        activeCtrls['control1Units']=Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"AUGER%",width:'60%',height:'50%',left: '0%',top: '50%'}));
        activeCtrls['mode1']=Titanium.UI.createLabel(uiStyle._extend(uiStyle.textButtonGreen,{text:"AUTO",width:'35%',height:'44%',left: '60%',top: '5%'}));
        activeCtrls['product']=Titanium.UI.createLabel(uiStyle._extend(uiStyle.textButtonGreen,{text:"MAIN",width:'35%',height:'44%',left: '60%',top: '50%'}));
        views['control1'].add(activeCtrls['control1']);
        views['control1'].add(activeCtrls['control1Units']);
        views['control1'].add(activeCtrls['mode1']);
        views['control1'].add(activeCtrls['product']);
        cont.add(views['control1']);
        
        //control2 view
        views['control2'] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '32%',top: '63%',height: '36%',width: '25%'}));
        activeCtrls['control2']=Titanium.UI.createLabel(uiStyle._extend(uiStyle.textXLarge,{text:"OFF",width:'100%',height:'50%',left: '0%',top: '0%'}));
        activeCtrls['control2Units']=Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"LIQUID%",width:'100%',height:'50%',left: '0%',top: '50%'}));
        views['control2'].add(activeCtrls['control2']);
        views['control2'].add(activeCtrls['control2Units']);
        cont.add(views['control2']);
        
        //hot buttons 1 view
        views['hb1'] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '58%',top: '63%',height: '36%',width: '15%'}));
        activeCtrls['hotbutton1'] = Titanium.UI.createLabel(uiStyle._extend(uiStyle.stdButton,{text:"",width:'80%',height:'44%',left: '10%',top: '5%',visible: false}));
        activeCtrls['hotbutton2'] = Titanium.UI.createLabel(uiStyle._extend(uiStyle.stdButton,{text:"",width:'80%',height:'44%',left: '10%',top: '50%',visible: false}));
        views['hb1'].add(activeCtrls['hotbutton1']);
        views['hb1'].add(activeCtrls['hotbutton2']);
        cont.add(views['hb1']);
        
        //control 3 view
        views['control3'] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '74%',top: '63%',height: '36%',width: '25%'}));
        activeCtrls['control3']=Titanium.UI.createLabel(uiStyle._extend(uiStyle.textXLarge,{text:"OFF",width:'100%',height:'50%',left: '0%',top: '0%'}));
        activeCtrls['control3Units']=Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"SPINNER %",width:'100%',height:'50%',left: '0%',top: '50%'}));
        views['control3'].add(activeCtrls['control3']);
        views['control3'].add(activeCtrls['control3Units']);
        cont.add(views['control3']);
        
        views['control4'].setVisible(false);
        views['booms'].setVisible(false);
        init = true;
    },
    /*!
     * This function opens the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@munciepower.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'open': function(){
        window.open();
    },
    /*!
     * This function closes the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@munciepower.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'close': function(){
        window.close();
    },
    /*!
     * This function updates the active controls on the current window view
     * with new data pushed from the stack.
     *
     * @author Kevin Wijesekera <kwijesekera@munciepower.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @param data JSON data object
     */
    'update': function(data){
        var d;
        if(!init || !data || !data.d || !data.d[0] || !data.s.rt){
            return;
        }
        
        d = data.d[0];
        
        //anti-ice mode
        if(d.gui[0] == 100){
            views['control4'].setVisible(true);
            views['booms'].setVisible(true);
            views['control1'].setVisible(false);
            views['control2'].setVisible(false);
            views['control3'].setVisible(false);
            views['hb1'].setVisible(false);
            views['totals'].setVisible(false);
        }
        //xzalt mode
        else if(d.gui[0] == 2){
            
        }
        //standard mode
        else{
            views['control4'].setVisible(false);
            views['booms'].setVisible(false);
            views['control1'].setVisible(true);
            views['control2'].setVisible(true);
            views['control3'].setVisible(true);
            views['hb1'].setVisible(true);
            views['totals'].setVisible(true);
        }
        
        //datalogging
        activeCtrls['prodTotal'].value(data.s.cfg.cmd);
        activeCtrls['liqTotal'].value(data.s.cfg.cmd);
        activeCtrls['msg-btn'].value(data.s.cfg.cmd);
        activeCtrls['prodTotal'].display(style._numberToString(d.dl[0],0,7));
        activeCtrls['liqTotal'].display(style._numberToString(d.dl[2],0,7));
        
        //control box 1
        if(d.gui[1]){
            activeCtrls['control1'].text = style._numberToString(d.gui[6][0],0,4);
        }
        else{
            activeCtrls['control1'].text = style._numberToString(d.gui[6][0],0,3);
        }
        activeCtrls['control1Units'].text = d.gui[6][1];
        activeCtrls['mode1'].text = (d.gui[1])?'AUTO':'MAN';
        activeCtrls['product'].text = d.gui[2];
        
        //control box 2 + 4 (duplicates)
        activeCtrls['control2'].text = style._numberToString(d.gui[7][0],0,3);
        activeCtrls['control2Units'].text = d.gui[7][1];
        activeCtrls['control4'].text = style._numberToString(d.gui[6][0],0,3);
        activeCtrls['control4Units'].text = d.gui[6][1];
        activeCtrls['mode2'].text = (d.gui[1])?'AUTO':'MAN';
        
        //control box 3
        activeCtrls['control3'].text = style._numberToString(d.gui[8][0],0,3);
        activeCtrls['control3Units'].text = d.gui[8][1];
        
        //hot button 1/boom left
        activeCtrls['hotbutton1'].text = d.gui[9][0];
        activeCtrls['hotbutton1'].backgroundColor = (d.gui[9][1])?'#D92B00':'#009933';
        activeCtrls['hotbutton1'].visible = d.gui[9][0] != "";
        activeCtrls['leftBoom'].backgroundColor = (d.gui[9][1])?'#D92B00':'#009933';
        
        //hot button 2/boom center
        activeCtrls['hotbutton2'].text = d.gui[10][0];
        activeCtrls['hotbutton2'].backgroundColor = (d.gui[10][1])?'#D92B00':'#009933';
        activeCtrls['hotbutton2'].visible = d.gui[10][0] != "";
        activeCtrls['centerBoom'].backgroundColor = (d.gui[10][1])?'#D92B00':'#009933';
        
        //hot button 3/boom right
        activeCtrls['rightBoom'].backgroundColor = (d.gui[11][1])?'#D92B00':'#009933';
        
        //joystick/wifi
        activeCtrls['joystick'].text = d.gui[12];
        
        //temp box
        activeCtrls['airTemp'].text = style._numberToString(d.gui[13],0,2);
        activeCtrls['roadTemp'].text = style._numberToString(d.gui[14],0,2);
        
        //pressure box
        activeCtrls['pumpPress'].text = style._numberToString(d.gui[15],0,4);
        activeCtrls['loadPress'].text = style._numberToString(d.gui[16],0,4);
        
        //alert
        if(typeof(data.s.rt.msg) == 'string'){
            d = data.s.rt.msg.split(';');
            activeCtrls['msg'].text = d[0];
        }
    },
    /*!
     * This function gets an object of data to send back to the server
     * based on any user requested actions
     *
     * @author Kevin Wijesekera <kwijesekera@munciepower.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @return object of data
     */
    'getDataTx': function(){
        var temp = sendBack;
        sendBack = {};
        return temp;
    }
    
};