/*!
 * @file 2-system.js
 *
 * @author Kevin Wijesekera <kwijesekera@munciepower.com>
 * @note Designed with Titanium for iOS and Android devices
 * @note This file contains propritary information
 * @copyright 2014 Riverside MFG LLC
 * @section DESCRIPTION
 *
 * This source file contains the class to draw/update window: 2-system
 */

var window;                /*!< Window object for self */
var activeCtrls = {};    /*!< Controls on window object */
var sendBack = {};
var init = false;

module.exports = {
    /*!
     * This flag determins if the current window should be skipped in the rotation of windows
     */
    'skip': false,
    /*!
     * This function is called to switch to config mode and should be remapped by the WindowManager
     */
    'switchToConfig': function(){},
    /*!
     * This function sets up the display elements for the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@munciepower.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'init': function(uiStyle,swipe,actionControllers){
        var cont,views=[];
        window = Titanium.UI.createWindow(uiStyle._extend(uiStyle.window, {
            title:'System Controls'
        }));
        cont = Titanium.UI.createView(uiStyle.containerCanvas);
        window.add(cont);
        window.addEventListener('swipe',swipe);
        window.addEventListener('android:back',function(e){
			back();
        	window.close();
        });
        
        //screen brightness
        views[0] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '1%',height: '31%',width: '48%'}));
        views[0].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"SCREEN BRIGHTNESS",width:'100%',height:'30%',left: '0',top: '0'})));
        activeCtrls["screenBright"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"100%",width:'40%',top: '40%'}),function(toSend){
            sendBack['rt'] = {'sys':{'0':toSend}};
        },false,{min:0,max:100,inc:5,multi:1,units:'%'});
        views[0].add(activeCtrls["screenBright"].getObject());
    
        //button brightness
        views[1] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '50%',top: '1%',height: '31%',width: '48%'}));
        views[1].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"BUTTON BRIGHTNESS",width:'100%',height:'30%',left: '0',top: '0'})));
        activeCtrls["buttonBright"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"100%",width:'40%',top: '40%'}),function(toSend){
            sendBack['rt'] = {'sys':{'1':toSend}};
        },false,{min:0,max:100,inc:5,multi:1,units:'%'});
        views[1].add(activeCtrls["buttonBright"].getObject());
        
        //Day Night
        views[2] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '34%',height: '31%',width: '48%'}));    
        views[2].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"BRIGHTNESS SETTING",width:'100%',height:'30%',left: '0',top: '0'})));
        activeCtrls["dayNight"] = new actionControllers.ToggleButton(uiStyle._extend(uiStyle.stdButton,{title:"100%",width:'40%',top: '40%'}),function(toSend){
            sendBack['rt'] = {'sys':{'3':toSend}};
        },[{val:false,text:'Night'},{val:true,text:'Day'}]);
        activeCtrls["dayNight"].value(0);
        views[2].add(activeCtrls["dayNight"].getObject());
        
        //Volume
        views[3] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '50%',top: '34%',height: '31%',width: '48%'}));
        views[3].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"VOLUME",width:'100%',height:'30%',left: '0',top: '0'})));
        activeCtrls["volume"] = new actionControllers.SliderButton(uiStyle._extend(uiStyle.stdButton,{title:"100%",width:'40%',top: '40%'}),function(toSend){
            sendBack['rt'] = {'sys':{'2':toSend}};
        },false,{min:0,max:100,inc:1,multi:1,units:'%'});
        views[3].add(activeCtrls["volume"].getObject());
        
        //configuration menu
        views[4] = Titanium.UI.createView(uiStyle._extend(uiStyle.container,{left: '1%',top: '68%',height: '31%',width: '48%'}));
        views[4].add(Titanium.UI.createLabel(uiStyle._extend(uiStyle.textSmall,{text:"CONFIGURATION MENU",width:'100%',height:'30%',left: '0',top: '0'})));
        activeCtrls["cfgEnter"] = Titanium.UI.createButton(uiStyle._extend(uiStyle.stdButton,{title:"Enter",width:'40%',top: '40%'}));
        activeCtrls["cfgEnter"].addEventListener('click', function(e){
            module.exports.switchToConfig();
        });
        views[4].add(activeCtrls["cfgEnter"]);
        
        for(var i=0;i<views.length;i++){
            cont.add(views[i]);
        }
        init = true;
    },
    /*!
     * This function opens the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@munciepower.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'open': function(){
        window.open();
    },
    /*!
     * This function closes the current window view
     *
     * @author Kevin Wijesekera <kwijesekera@munciepower.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     */
    'close': function(){
        window.close();
    },
    /*!
     * This function updates the active controls on the current window view
     * with new data pushed from the stack.
     *
     * @author Kevin Wijesekera <kwijesekera@munciepower.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @param data JSON data object
     */
    'update': function(data){
        if(!init || !data || !data.d || !data.d[0]){
            return;
        }
        activeCtrls["screenBright"].value(data.d[0].sys[0]);
        activeCtrls["buttonBright"].value(data.d[0].sys[1]);
        activeCtrls["volume"].value(data.d[0].sys[2]);
        activeCtrls["dayNight"].value(data.d[0].sys[3]);
    },
    /*!
     * This function gets an object of data to send back to the server
     * based on any user requested actions
     *
     * @author Kevin Wijesekera <kwijesekera@munciepower.com>
     * @date 11/25/2014
     * @note Designed with Titanium API ver. 3.4.1
     * 
     * @return object of data
     */
    'getDataTx': function(){
        var temp = sendBack;
        sendBack = {};
        return temp;
    }
    
};