/*!
* @file         app.js
* @author       Kevin Wijesekera
* @note         Designed with Titanium API ver 3.0 
* @copyright    Copyright (c) 2013 Riverside MFG LLC
* @section DESCRIPTION
*
* This source file is the entry location for the advantage+ android app
* it sets up the main window and starts the TCP comm
*/

// *** Inclues ***
var connectionMgr = require('UI/ConnectionMgr');
var networkMgr = require('NetworkManager');
var windowMgr = require('UI/WindowManager');

// *** Window Manager (Main View) ***
windowMgr.init(onPauseEvent);

// *** Setup Network Manager (WiFi Link) ***
networkMgr.init(function(data){
    //rx callback
    try{
        data = JSON.parse(data);
    }
    catch(e){
        Ti.API.log(data);
        Ti.API.log('(app.js): Could not JSON Decode data!');
        data = false;
    }
    if(typeof(data) != 'object' || !data == null){
        data = false;
        Ti.API.log('(app.js): Invalid data passed!');
    }
    else if(typeof(data.s) != 'object' || !data.s){
        data = false;
        Ti.API.log('(app.js): Invalid data passed!');
    }
    else if(typeof(data.s.cfg) != 'object' || !data.s.cfg){
        data = false;
        Ti.API.log('(app.js): Invalid data passed!');
    }
    
    if(windowMgr.isRunning()){
        windowMgr.pushData(data);
        networkMgr.tx(windowMgr.getDataTx());
    }
    else{
        connectionMgr.pushData(data);
    }

},function(){
    //timeout callback
    if(windowMgr.isRunning()){
    	Ti.API.log('Connection timed out!');
        networkMgr.stop();
        connectionMgr.open();
        windowMgr.close();
    }
});

// *** Setup Connection Manager (Connection Screen) ***
connectionMgr.init(function(host){
    //start callback
    networkMgr.start(host,52345);
},function(){
    //stop callback
    networkMgr.stop();
},function(){
    //success callback
    windowMgr.open();
    connectionMgr.close();
    
});
connectionMgr.open();

// *** Pause and Resume actions ***
Ti.App.addEventListener('paused',onPauseEvent);
Ti.App.addEventListener('resume',onResumeEvent);   
if(Ti.Platform.name == 'android'){
    var platformTools = require('bencoding.android.tools').createPlatform(),
        wasInForeGround = true;

    setInterval(function() {
        var isInForeground = platformTools.isInForeground();

        if (wasInForeGround !== isInForeground) {
            Ti.App.fireEvent(isInForeground ? 'resumed' : 'paused');

            wasInForeGround = isInForeground;
        }
    }, 3000);
}

/*!
 * This function handles the current application pause event
 *
 * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
 * @date 11/21/2014
 * @note Designed with Titanium API ver. 3.4.1
 */
function onPauseEvent(){
    Ti.API.log('*** Action: PAUSED ***');
    networkMgr.stop();
}

/*!
 * This function handles the current window resume event
 *
 * @author Kevin Wijesekera <kwijesekera@riversidemfg.com>
 * @date 11/21/2014
 * @note Designed with Titanium API ver. 3.4.1
 */
function onResumeEvent(){
    Ti.API.log('*** Action: RESUME ***');
    connectionMgr.open();
    windowMgr.close();
}

